@@ -1,7 +1,6 @@
 #!/bin/bash
 set -eu
-
-for f in "$@"; do
+find ./tests_ok ./tests_failed -maxdepth 1 -type f -name '*.curl' ! -name '*windows*'|sort | while read -r f; do
     echo "** $f"
     grep -v '^$' <"$f" | grep -v '^#' | while read -r line;  do
         echo "$line"
