@@ -6,13 +6,12 @@ import sys
 import subprocess
 import os
 import platform
-import check_json_output
 import re
 import argparse
 
 
 def decode_string(encoded: bytes) -> str:
-    """Decodes bytes to string from infering encoding."""
+    """Decodes bytes to string from inferring encoding."""
     if encoded.startswith(codecs.BOM_UTF8):
         return encoded.decode("utf-8-sig")
     elif encoded.startswith(codecs.BOM_UTF16):
@@ -36,7 +35,7 @@ def get_os() -> str:
     elif platform.system() == "Windows":
         return "windows"
     else:
-        raise Error("Invalid Platform " + platform.system())
+        raise ValueError("Invalid Platform " + platform.system())
 
 
 def test(hurl_file: str):
@@ -55,7 +54,6 @@ def test(hurl_file: str):
     else:
         curl_file = hurl_file.replace(".hurl", ".curl")
 
-    json_output_file = hurl_file.replace(".hurl", ".output.json")
     profile_file = hurl_file.replace(".hurl", ".profile")
 
     options = []
@@ -64,9 +62,6 @@ def test(hurl_file: str):
     if os.path.exists(curl_file):
         options.append("--verbose")
 
-    if os.path.exists(json_output_file):
-        options.append("--json")
-
     env = os.environ.copy()
     if os.path.exists(profile_file):
         for line in open(profile_file, encoding="utf-8").readlines():
@@ -131,12 +126,6 @@ def test(hurl_file: str):
                 )
                 sys.exit(1)
 
-    # stdout (json)
-    if os.path.exists(json_output_file):
-        expected = open(json_output_file, encoding="utf-8").read()
-        actual = result.stdout
-        check_json_output.check(expected, actual)
-
     # stderr
     f = hurl_file.replace(".hurl", ".err")
     if os.path.exists(f):
@@ -152,6 +141,12 @@ def test(hurl_file: str):
     if os.path.exists(f):
         expected = open(f, encoding="utf-8").read()
         actual = decode_string(result.stderr)
+
+        # curl debug logs are too dependent on the context, so we filter
+        # them and not take them into account for testing differences.
+        expected = remove_curl_debug_lines(expected)
+        actual = remove_curl_debug_lines(actual)
+
         expected_lines = expected.split("\n")
         expected_pattern_lines = [parse_pattern(line) for line in expected_lines]
         actual_lines = re.split(r"\r?\n", actual)
@@ -201,7 +196,7 @@ def test(hurl_file: str):
 def parse_pattern(s: str) -> str:
     """Transform a stderr pattern to a regex"""
     # Escape regex metacharacters
-    for c in ["\\", ".", "(", ")", "[", "]", "^", "$", "*", "+", "?"]:
+    for c in ["\\", ".", "(", ")", "[", "]", "^", "$", "*", "+", "?", "|"]:
         s = s.replace(c, "\\" + c)
 
     s = re.sub("~+", ".*", s)
@@ -209,6 +204,13 @@ def parse_pattern(s: str) -> str:
     return s
 
 
+def remove_curl_debug_lines(text: str) -> str:
+    """Removes curl debug logs from text and returns the new text."""
+    lines = text.split("\n")
+    lines = [line for line in lines if not line.startswith("**")]
+    return "\n".join(lines)
+
+
 def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("file", type=str, nargs="+", metavar="FILE")
