@@ -24,13 +24,12 @@ use std::path::{Path, PathBuf};
 use std::time::Duration;
 
 use atty::Stream;
-use clap::{AppSettings, ArgAction, ArgMatches, Command};
+use clap::{value_parser, ArgAction, ArgMatches, Command};
 
 use crate::cli;
 use crate::cli::CliError;
 use crate::http::ClientOptions;
 use crate::runner::Value;
-use crate::util::logger::BaseLogger;
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct CliOptions {
@@ -54,9 +53,11 @@ pub struct CliOptions {
     pub no_proxy: Option<String>,
     pub output: Option<String>,
     pub output_type: OutputType,
-    pub progress: bool,
     pub proxy: Option<String>,
-    pub summary: bool,
+    pub retry: bool,
+    pub retry_interval: Duration,
+    pub retry_max_count: Option<usize>,
+    pub test: bool,
     pub timeout: Duration,
     pub to_entry: Option<usize>,
     pub user: Option<String>,
@@ -74,241 +75,299 @@ pub enum OutputType {
 }
 
 pub fn app(version: &str) -> Command {
+    let ClientOptions {
+        connect_timeout: default_connect_timeout,
+        max_redirect: default_max_redirect,
+        retry_max_count: default_retry_max_count,
+        timeout: default_timeout,
+        ..
+    } = ClientOptions::default();
+
+    let default_connect_timeout = default_connect_timeout.as_secs();
+    let default_max_redirect = default_max_redirect.unwrap();
+    let default_timeout = default_timeout.as_secs();
+    let default_retry_max_count = default_retry_max_count.unwrap();
+
     Command::new("hurl")
-        .about("Run hurl FILE(s) or standard input")
-        .setting(AppSettings::DeriveDisplayOrder)
+        .about("Run Hurl file(s) or standard input")
         .disable_colored_help(true)
-        .version(version)
+        .version(version.to_string())
         .arg(
-            clap::Arg::new("INPUT")
+            clap::Arg::new("FILE")
                 .help("Sets the input file to use")
                 .required(false)
-                .multiple_values(true),
+                .num_args(1..)
         )
         .arg(
             clap::Arg::new("cacert_file")
                 .long("cacert")
                 .value_name("FILE")
-                .help("CA certificate to verify peer against (PEM format)"),
+                .help("CA certificate to verify peer against (PEM format)")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("color")
                 .long("color")
+                .help("Colorize output")
+                .action(ArgAction::SetTrue)
                 .conflicts_with("no_color")
-                .help("Colorize Output"),
         )
         .arg(
             clap::Arg::new("compressed")
                 .long("compressed")
-                .help("Request compressed response (using deflate or gzip)"),
+                .help("Request compressed response (using deflate or gzip)")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("connect_timeout")
                 .long("connect-timeout")
                 .value_name("SECONDS")
-                .help("Maximum time allowed for connection"),
+                .help("Maximum time allowed for connection")
+                .default_value(default_connect_timeout.to_string())
+                .value_parser(value_parser!(u64))
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("cookies_input_file")
                 .short('b')
                 .long("cookie")
                 .value_name("FILE")
-                .help("Read cookies from FILE"),
+                .help("Read cookies from FILE")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("cookies_output_file")
                 .short('c')
                 .long("cookie-jar")
                 .value_name("FILE")
-                .help("Write cookies to FILE after running the session (only for one session)"),
+                .help("Write cookies to FILE after running the session (only for one session)")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("fail_at_end")
                 .long("fail-at-end")
                 .help("Fail at end")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("file_root")
                 .long("file-root")
                 .value_name("DIR")
-                .help("set root filesystem to import file in hurl (default is current directory)")
-                .takes_value(true),
+                .help("Set root filesystem to import files (default is current directory)")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("follow_location")
                 .short('L')
                 .long("location")
-                .help("Follow redirects"),
+                .help("Follow redirects")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("glob")
                 .long("glob")
                 .value_name("GLOB")
+                .help("Specify input files that match the given GLOB. Multiple glob flags may be used")
                 .action(ArgAction::Append)
                 .number_of_values(1)
-                .help("Specify input files that match the given blob. Multiple glob flags may be used."),
         )
         .arg(
             clap::Arg::new("include")
                 .short('i')
                 .long("include")
-                .help("Include the HTTP headers in the output"),
+                .help("Include the HTTP headers in the output")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("ignore_asserts")
                 .long("ignore-asserts")
-                .help("Ignore asserts defined in the Hurl file."),
+                .help("Ignore asserts defined in the Hurl file")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("insecure")
                 .short('k')
                 .long("insecure")
-                .help("Allow insecure SSL connections"),
+                .help("Allow insecure SSL connections")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("interactive")
                 .long("interactive")
+                .help("Turn on interactive mode")
                 .conflicts_with("to_entry")
-                .help("Turn on interactive mode"),
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("json")
                 .long("json")
+                .help("Output each Hurl file result to JSON")
                 .conflicts_with("no_output")
-                .help("Output each hurl file result to JSON"),
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("max_redirects")
                 .long("max-redirs")
                 .value_name("NUM")
+                .help("Maximum number of redirects allowed, -1 for unlimited redirects")
+                .default_value(default_max_redirect.to_string())
                 .allow_hyphen_values(true)
-                .help("Maximum number of redirects allowed"),
+                .value_parser(value_parser!(i32).range(-1..))
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("max_time")
                 .long("max-time")
                 .short('m')
-                .value_name("NUM")
+                .value_name("SECONDS")
+                .help("Maximum time allowed for the transfer")
+                .default_value(default_timeout.to_string())
                 .allow_hyphen_values(true)
-                .help("Maximum time allowed for the transfer"),
+                .value_parser(value_parser!(u64))
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("no_color")
                 .long("no-color")
+                .help("Do not colorize output")
                 .conflicts_with("color")
-                .help("Do not colorize Output"),
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("no_output")
                 .long("no-output")
+                .help("Suppress output. By default, Hurl outputs the body of the last response")
                 .conflicts_with("json")
-                .help("Suppress output. By default, Hurl outputs the body of the last response."),
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("noproxy")
                 .long("noproxy")
                 .value_name("HOST(S)")
                 .help("List of hosts which do not use proxy")
-                .takes_value(true),
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("output")
                 .short('o')
                 .long("output")
                 .value_name("FILE")
-                .help("Write to FILE instead of stdout"),
-        )
-        .arg(
-            clap::Arg::new("progress")
-                .long("progress")
-                .help("Print filename and status for each test (stderr) - deprecated use --test"),
+                .help("Write to FILE instead of stdout")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("proxy")
                 .short('x')
                 .long("proxy")
                 .value_name("[PROTOCOL://]HOST[:PORT]")
-                .help("Use proxy on given protocol/host/port"),
+                .help("Use proxy on given protocol/host/port")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("junit")
                 .long("report-junit")
                 .value_name("FILE")
-                .help("Write a Junit XML report to the given file")
-                .takes_value(true),
+                .help("Write a Junit XML report to FILE")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("report_html")
                 .long("report-html")
                 .value_name("DIR")
-                .help("Generate html report to dir")
-                .takes_value(true),
+                .help("Generate HTML report to DIR")
+                .num_args(1)
         )
         .arg(
-            clap::Arg::new("summary")
-                .long("summary")
-                .help("Print test metrics at the end of the run (stderr) - deprecated use --test"),
+            clap::Arg::new("retry")
+                .long("retry")
+                .help("Retry requests on errors")
+                .action(ArgAction::SetTrue)
+        )
+        .arg(
+            clap::Arg::new("retry_interval")
+                .long("retry-interval")
+                .value_name("MILLISECONDS")
+                .help("Interval in milliseconds before a retry")
+                .value_parser(value_parser!(u64))
+                .default_value("1000")
+                .num_args(1)
+        )
+        .arg(
+            clap::Arg::new("retry_max_count")
+                .long("retry-max-count")
+                .value_name("NUM")
+                .help("Maximum number of retries, -1 for unlimited retries")
+                .default_value(default_retry_max_count.to_string())
+                .allow_hyphen_values(true)
+                .value_parser(value_parser!(i32).range(-1..))
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("test")
                 .long("test")
-                .help("Activate test mode."),
+                .help("Activate test mode")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("to_entry")
                 .long("to-entry")
                 .value_name("ENTRY_NUMBER")
+                .help("Execute Hurl file to ENTRY_NUMBER (starting at 1)")
                 .conflicts_with("interactive")
-                .help("Execute hurl file to ENTRY_NUMBER (starting at 1)")
-                .takes_value(true),
+                .allow_hyphen_values(true)
+                .value_parser(value_parser!(u32).range(1..))
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("user")
                 .short('u')
                 .long("user")
-                .value_name("user:password")
-                .help("Add basic Authentication header to each request.")
-                .takes_value(true),
+                .value_name("USER:PASSWORD")
+                .help("Add basic Authentication header to each request")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("user_agent")
                 .short('A')
                 .long("user-agent")
-                .value_name("name")
-                .help("Specify the User-Agent string to send to the HTTP server.")
-                .takes_value(true),
+                .value_name("NAME")
+                .help("Specify the User-Agent string to send to the HTTP server")
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("variable")
                 .long("variable")
                 .value_name("NAME=VALUE")
+                .help("Define a variable")
                 .action(ArgAction::Append)
                 .number_of_values(1)
-                .help("Define a variable")
-                .takes_value(true),
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("variables_file")
                 .long("variables-file")
                 .value_name("FILE")
                 .help("Define a properties file in which you define your variables")
-                .takes_value(true),
+                .num_args(1)
         )
         .arg(
             clap::Arg::new("verbose")
                 .short('v')
                 .long("verbose")
-                .help("Turn on verbose output"),
+                .help("Turn on verbose output")
+                .action(ArgAction::SetTrue)
         )
         .arg(
             clap::Arg::new("very_verbose")
                 .long("very-verbose")
-                .help("Turn on verbose output, uncluding HTTP response"),
+                .help("Turn on verbose output, including HTTP response and libcurl logs")
+                .action(ArgAction::SetTrue)
         )
 }
 
-pub fn parse_options(matches: &ArgMatches, logger: &BaseLogger) -> Result<CliOptions, CliError> {
-    let cacert_file = match get_string(matches, "cacert_file") {
+/// Parses command line options `matches`.
+pub fn parse_options(matches: &ArgMatches) -> Result<CliOptions, CliError> {
+    let cacert_file = match get::<String>(matches, "cacert_file") {
         None => None,
         Some(filename) => {
             if !Path::new(&filename).is_file() {
@@ -321,24 +380,15 @@ pub fn parse_options(matches: &ArgMatches, logger: &BaseLogger) -> Result<CliOpt
     };
     let color = output_color(matches);
     let compressed = has_flag(matches, "compressed");
-    let connect_timeout = match get_string(matches, "connect_timeout") {
-        None => ClientOptions::default().connect_timeout,
-        Some(s) => match s.parse::<u64>() {
-            Ok(n) => Duration::from_secs(n),
-            Err(_) => {
-                return Err(CliError {
-                    message: "connect-timeout option can not be parsed".to_string(),
-                });
-            }
-        },
-    };
-    let cookie_input_file = get_string(matches, "cookies_input_file");
-    let cookie_output_file = get_string(matches, "cookies_output_file");
+    let connect_timeout = get::<u64>(matches, "connect_timeout").unwrap();
+    let connect_timeout = Duration::from_secs(connect_timeout);
+    let cookie_input_file = get::<String>(matches, "cookies_input_file");
+    let cookie_output_file = get::<String>(matches, "cookies_output_file");
     let fail_fast = !has_flag(matches, "fail_at_end");
-    let file_root = get_string(matches, "file_root");
+    let file_root = get::<String>(matches, "file_root");
     let follow_location = has_flag(matches, "follow_location");
     let glob_files = match_glob_files(matches)?;
-    let report_html = get_string(matches, "report_html");
+    let report_html = get::<String>(matches, "report_html");
     let html_dir = if let Some(dir) = report_html {
         let path = Path::new(&dir);
         if !path.exists() {
@@ -364,21 +414,14 @@ pub fn parse_options(matches: &ArgMatches, logger: &BaseLogger) -> Result<CliOpt
     let include = has_flag(matches, "include");
     let insecure = has_flag(matches, "insecure");
     let interactive = has_flag(matches, "interactive");
-    let junit_file = get_string(matches, "junit");
-    let max_redirect = match get_string(matches, "max_redirects").as_deref() {
-        None => Some(50),
-        Some("-1") => None,
-        Some(s) => match s.parse::<usize>() {
-            Ok(x) => Some(x),
-            Err(_) => {
-                return Err(CliError {
-                    message: "max_redirs option can not be parsed".to_string(),
-                });
-            }
-        },
+    let junit_file = get::<String>(matches, "junit");
+    let max_redirect = get::<i32>(matches, "max_redirects").unwrap();
+    let max_redirect = match max_redirect {
+        m if m == -1 => None,
+        m => Some(m as usize),
     };
-    let no_proxy = get_string(matches, "proxy");
-    let output = get_string(matches, "output");
+    let no_proxy = get::<String>(matches, "proxy");
+    let output = get::<String>(matches, "output");
     let test = has_flag(matches, "test");
     let output_type = if has_flag(matches, "json") {
         OutputType::Json
@@ -387,36 +430,21 @@ pub fn parse_options(matches: &ArgMatches, logger: &BaseLogger) -> Result<CliOpt
     } else {
         OutputType::ResponseBody
     };
-    let progress = has_flag(matches, "progress");
-    if progress {
-        logger.warning(
-            "--progress option is deprecated and will be removed soon. Please use --test or --json",
-        );
-    }
-    let progress = progress || test;
-    let proxy = get_string(matches, "proxy");
-    let summary = has_flag(matches, "summary");
-    if summary {
-        logger.warning(
-            "--summary option is deprecated and will be removed soon. Please use --test or --json",
-        );
-    }
-    let summary = summary || test;
-    let timeout = match get_string(matches, "max_time") {
-        None => ClientOptions::default().timeout,
-        Some(s) => match s.parse::<u64>() {
-            Ok(n) => Duration::from_secs(n),
-            Err(_) => {
-                return Err(CliError {
-                    message: "max_time option can not be parsed".to_string(),
-                });
-            }
-        },
+    let proxy = get::<String>(matches, "proxy");
+    let retry = has_flag(matches, "retry");
+    let retry_interval = get::<u64>(matches, "retry_interval").unwrap();
+    let retry_interval = Duration::from_millis(retry_interval);
+    let retry_max_count = get::<i32>(matches, "retry_max_count").unwrap();
+    let retry_max_count = match retry_max_count {
+        r if r == -1 => None,
+        r => Some(r as usize),
     };
-    let to_entry = to_entry(matches)?;
-    let user = get_string(matches, "user");
-    let user_agent = get_string(matches, "user_agent");
-    let variables = variables(matches.clone())?;
+    let timeout = get::<u64>(matches, "max_time").unwrap();
+    let timeout = Duration::from_secs(timeout);
+    let to_entry = get::<u32>(matches, "to_entry").map(|x| x as usize);
+    let user = get::<String>(matches, "user");
+    let user_agent = get::<String>(matches, "user_agent");
+    let variables = variables(matches)?;
     let very_verbose = has_flag(matches, "very_verbose");
     let verbose = has_flag(matches, "verbose") || has_flag(matches, "interactive") || very_verbose;
 
@@ -441,9 +469,11 @@ pub fn parse_options(matches: &ArgMatches, logger: &BaseLogger) -> Result<CliOpt
         no_proxy,
         output,
         output_type,
-        progress,
         proxy,
-        summary,
+        retry,
+        retry_interval,
+        retry_max_count,
+        test,
         timeout,
         to_entry,
         user,
@@ -470,23 +500,11 @@ pub fn output_color(matches: &ArgMatches) -> bool {
     atty::is(Stream::Stdout)
 }
 
-fn to_entry(matches: &ArgMatches) -> Result<Option<usize>, CliError> {
-    match get_string(matches, "to_entry") {
-        Some(value) => match value.parse() {
-            Ok(v) => Ok(Some(v)),
-            Err(_) => Err(CliError {
-                message: "Invalid value for option --to-entry - must be a positive integer!"
-                    .to_string(),
-            }),
-        },
-        None => Ok(None),
-    }
-}
-
-fn variables(matches: ArgMatches) -> Result<HashMap<String, Value>, CliError> {
+/// Returns a map of variables from the command line options `matches`.
+fn variables(matches: &ArgMatches) -> Result<HashMap<String, Value>, CliError> {
     let mut variables = HashMap::new();
 
-    // use environment variables prefix by HURL_
+    // Use environment variables prefix by HURL_
     for (env_name, env_value) in env::vars() {
         if let Some(name) = env_name.strip_prefix("HURL_") {
             let value = cli::parse_variable_value(env_value.as_str())?;
@@ -494,7 +512,7 @@ fn variables(matches: ArgMatches) -> Result<HashMap<String, Value>, CliError> {
         }
     }
 
-    if let Some(filename) = get_string(&matches, "variables_file") {
+    if let Some(filename) = get::<String>(matches, "variables_file") {
         let path = Path::new(&filename);
         if !path.exists() {
             return Err(CliError {
@@ -522,7 +540,7 @@ fn variables(matches: ArgMatches) -> Result<HashMap<String, Value>, CliError> {
         }
     }
 
-    if let Some(input) = get_strings(&matches, "variable") {
+    if let Some(input) = get_strings(matches, "variable") {
         for s in input {
             let (name, value) = cli::parse_variable(&s)?;
             variables.insert(name.to_string(), value);
@@ -532,12 +550,7 @@ fn variables(matches: ArgMatches) -> Result<HashMap<String, Value>, CliError> {
     Ok(variables)
 }
 
-///
-/// Returns a list of path names that match `matches`.
-///
-/// # Arguments
-/// * `matches` - A pattern to be matched
-///
+/// Returns a list of path names from the command line options `matches`.
 fn match_glob_files(matches: &ArgMatches) -> Result<Vec<String>, CliError> {
     let mut filenames = vec![];
     if let Some(exprs) = get_strings(matches, "glob") {
@@ -572,8 +585,9 @@ fn match_glob_files(matches: &ArgMatches) -> Result<Vec<String>, CliError> {
     Ok(filenames)
 }
 
-fn get_string(matches: &ArgMatches, name: &str) -> Option<String> {
-    matches.get_one::<String>(name).map(|x| x.to_string())
+/// Returns a optional value of type `T` from the command line `matches` given the option `name`.
+fn get<T: Clone + Send + Sync + 'static>(matches: &ArgMatches, name: &str) -> Option<T> {
+    matches.get_one::<T>(name).cloned()
 }
 
 pub fn get_strings(matches: &ArgMatches, name: &str) -> Option<Vec<String>> {
@@ -582,6 +596,7 @@ pub fn get_strings(matches: &ArgMatches, name: &str) -> Option<Vec<String>> {
         .map(|v| v.map(|x| x.to_string()).collect())
 }
 
+/// Returns true if the command line options `matches` has a given flag `name`.
 pub fn has_flag(matches: &ArgMatches, name: &str) -> bool {
-    matches.contains_id(name)
+    matches.get_one::<bool>(name) == Some(&true)
 }
