@@ -53,7 +53,7 @@ impl Client {
 
         // Activate cookie storage
         // with or without persistence (empty string)
-        h.cookie_file(cookie_input_file.unwrap_or_else(|| "".to_string()).as_str())
+        h.cookie_file(cookie_input_file.unwrap_or_default())
             .unwrap();
 
         Client {
@@ -82,12 +82,13 @@ impl Client {
         self.redirect_count = 0;
         loop {
             let (request, response) = self.execute(&request_spec, options, logger)?;
-            calls.push((request, response.clone()));
+            calls.push((request.clone(), response.clone()));
             if !options.follow_location {
                 break;
             }
 
-            if let Some(url) = self.get_follow_location(&response) {
+            let base_url = request.base_url()?;
+            if let Some(url) = self.get_follow_location(&response, &base_url) {
                 logger.debug("");
                 logger.debug(format!("=> Redirect to {}", url).as_str());
                 logger.debug("");
@@ -166,7 +167,7 @@ impl Client {
         self.set_headers(request_spec, options);
 
         let start = Instant::now();
-        let verbose = options.verbosity != None;
+        let verbose = options.verbosity.is_some();
         let very_verbose = options.verbosity == Some(Verbosity::VeryVerbose);
         let mut request_headers: Vec<Header> = vec![];
         let mut status_lines = vec![];
@@ -181,6 +182,10 @@ impl Client {
         // of key-value.
         let mut request_body = Vec::<u8>::new();
         let mut response_body = Vec::<u8>::new();
+
+        if *method == Method::Head {
+            self.handle.nobody(true).unwrap();
+        }
         {
             let mut transfer = self.handle.transfer();
             if !request_spec_body.is_empty() {
@@ -188,6 +193,7 @@ impl Client {
                     .read_function(|buf| Ok(request_spec_body.read(buf).unwrap_or(0)))
                     .unwrap();
             }
+
             transfer
                 .debug_function(|info_type, data| match info_type {
                     // Return all request headers (not one by one)
@@ -218,7 +224,7 @@ impl Client {
                                 body: Vec::new(),
                             };
                             for header in &debug_request.headers {
-                                logger.header_out(&header.name, &header.value);
+                                logger.debug_header_out(&header.name, &header.value);
                             }
                             logger.info(">");
 
@@ -239,7 +245,7 @@ impl Client {
                                 body: Vec::from(data),
                             };
                             for header in &debug_request.headers {
-                                logger.header_out(&header.name, &header.value);
+                                logger.debug_header_out(&header.name, &header.value);
                             }
                             logger.info(">");
 
@@ -248,6 +254,16 @@ impl Client {
                             }
                         }
                     }
+                    // Curl debug logs
+                    easy::InfoType::Text => {
+                        let len = data.len();
+                        if very_verbose && len > 0 {
+                            let text = str::from_utf8(&data[..len - 1]);
+                            if let Ok(text) = text {
+                                logger.debug_curl(text);
+                            }
+                        }
+                    }
                     _ => {}
                 })
                 .unwrap();
@@ -293,11 +309,11 @@ impl Client {
         };
         let headers = self.parse_response_headers(&response_headers);
         let duration = start.elapsed();
-        let lenght = response_body.len();
+        let length = response_body.len();
         self.handle.reset();
 
         let request = Request {
-            url,
+            url: url.clone(),
             method: method.to_string(),
             headers: request_headers,
             body: request_body,
@@ -308,13 +324,14 @@ impl Client {
             headers,
             body: response_body,
             duration,
+            url,
         };
 
         if verbose {
             logger.debug_important(
                 format!(
                     "Response: (received {} bytes in {} ms)",
-                    lenght,
+                    length,
                     duration.as_millis()
                 )
                 .as_str(),
@@ -325,10 +342,10 @@ impl Client {
             status_lines
                 .iter()
                 .filter(|s| s.starts_with("HTTP/"))
-                .for_each(|s| logger.status_version_in(s.trim()));
+                .for_each(|s| logger.debug_status_version_in(s.trim()));
 
             for header in &response.headers {
-                logger.header_in(&header.name, &header.value);
+                logger.debug_header_in(&header.name, &header.value);
             }
             logger.info("<");
             if very_verbose {
@@ -437,7 +454,7 @@ impl Client {
         }
     }
 
-    /// Sets multipart form datas.
+    /// Sets multipart form data.
     fn set_multipart(&mut self, params: &[MultipartParam]) {
         if !params.is_empty() {
             let mut form = easy::Form::new();
@@ -513,14 +530,14 @@ impl Client {
     /// 1. the option follow_location set to true
     /// 2. a 3xx response code
     /// 3. a header Location
-    fn get_follow_location(&mut self, response: &Response) -> Option<String> {
+    fn get_follow_location(&mut self, response: &Response, base_url: &str) -> Option<String> {
         let response_code = response.status;
         if !(300..400).contains(&response_code) {
             return None;
         }
         let location = match response.get_header_values("Location").get(0) {
             None => return None,
-            Some(value) => value.clone(),
+            Some(value) => get_redirect_url(value, base_url),
         };
 
         if location.is_empty() {
@@ -547,7 +564,7 @@ impl Client {
 
     /// Adds a cookie to the cookie jar.
     pub fn add_cookie(&mut self, cookie: &Cookie, options: &ClientOptions) {
-        if options.verbosity != None {
+        if options.verbosity.is_some() {
             eprintln!("* add to cookie store: {}", cookie);
         }
         self.handle
@@ -557,7 +574,7 @@ impl Client {
 
     /// Clears cookie storage.
     pub fn clear_cookie_storage(&mut self, options: &ClientOptions) {
-        if options.verbosity != None {
+        if options.verbosity.is_some() {
             eprintln!("* clear cookie storage");
         }
         self.handle.cookie_list("ALL").unwrap();
@@ -590,6 +607,15 @@ impl Client {
     }
 }
 
+/// Returns the redirect url.
+fn get_redirect_url(location: &str, base_url: &str) -> String {
+    if location.starts_with('/') {
+        format!("{}{}", base_url, location)
+    } else {
+        location.to_string()
+    }
+}
+
 /// Returns cookies from both cookies from the cookie storage and the request.
 pub fn all_cookies(cookie_storage: &[Cookie], request_spec: &RequestSpec) -> Vec<RequestCookie> {
     let mut cookies = request_spec.cookies.clone();
@@ -599,7 +625,7 @@ pub fn all_cookies(cookie_storage: &[Cookie], request_spec: &RequestSpec) -> Vec
             .filter(|c| c.expires != "1") // cookie expired when libcurl set value to 1?
             .filter(|c| match_cookie(c, request_spec.url.as_str()))
             .map(|c| RequestCookie {
-                name: (*c).name.clone(),
+                name: c.name.clone(),
                 value: c.value.clone(),
             })
             .collect(),
@@ -739,4 +765,16 @@ mod tests {
         assert!(match_cookie(&cookie, "http://sub.example.com/toto"));
         assert!(!match_cookie(&cookie, "http://example.com/tata"));
     }
+
+    #[test]
+    fn test_redirect_url() {
+        assert_eq!(
+            get_redirect_url("http://localhost:8000/redirected", "http://localhost:8000"),
+            "http://localhost:8000/redirected".to_string()
+        );
+        assert_eq!(
+            get_redirect_url("/redirected", "http://localhost:8000"),
+            "http://localhost:8000/redirected".to_string()
+        );
+    }
 }
