@@ -16,9 +16,13 @@
  *
  */
 
-pub use self::client::{Client, HttpError};
-pub use self::core::{Cookie, Header, Param, RequestCookie};
-pub use self::options::ClientOptions;
+pub use self::client::Client;
+pub use self::context_dir::ContextDir;
+pub use self::cookie::{CookieAttribute, ResponseCookie};
+pub use self::core::{Cookie, Param, RequestCookie};
+pub use self::error::HttpError;
+pub use self::header::Header;
+pub use self::options::{ClientOptions, Verbosity};
 pub use self::request::Request;
 #[cfg(test)]
 pub use self::request_spec::tests::*;
@@ -29,9 +33,21 @@ pub use self::response::{Response, Version};
 pub use self::version::libcurl_version_info;
 
 mod client;
+mod context_dir;
+mod cookie;
 mod core;
+mod debug;
+mod error;
+mod header;
+mod mimetype;
 mod options;
 mod request;
+mod request_debug;
+mod request_decoding;
 mod request_spec;
+mod request_spec_curl_args;
 mod response;
+mod response_cookie;
+mod response_debug;
+mod response_decoding;
 mod version;
