@@ -27,6 +27,7 @@ pub struct ClientOptions {
     pub no_proxy: Option<String>,
     pub verbosity: Option<Verbosity>,
     pub insecure: bool,
+    pub retry_max_count: Option<usize>,
     pub timeout: Duration,
     pub connect_timeout: Duration,
     pub user: Option<String>,
@@ -51,6 +52,7 @@ impl Default for ClientOptions {
             no_proxy: None,
             verbosity: None,
             insecure: false,
+            retry_max_count: Some(10),
             timeout: Duration::from_secs(300),
             connect_timeout: Duration::from_secs(300),
             user: None,
@@ -135,6 +137,7 @@ mod tests {
                 no_proxy: None,
                 verbosity: None,
                 insecure: true,
+                retry_max_count: Some(10),
                 timeout: Duration::from_secs(10),
                 connect_timeout: Duration::from_secs(20),
                 user: Some("user:password".to_string()),
