@@ -27,13 +27,14 @@ use colored::*;
 use hurl::cli;
 use hurl::cli::{CliError, CliOptions, Logger, OutputType};
 use hurl::http;
-use hurl::http::ContextDir;
+use hurl::http::Response;
 use hurl::report;
 use hurl::report::canonicalize_filename;
 use hurl::runner;
-use hurl::runner::{HurlResult, RunnerError, RunnerOptions, Verbosity};
+use hurl::runner::RunnerOptions;
+use hurl::runner::{HurlResult, RunnerError};
 use hurl::util::logger::BaseLogger;
-use hurl_core::ast::{Entry, Pos, SourceInfo};
+use hurl_core::ast::{Pos, SourceInfo};
 use hurl_core::error::Error;
 use hurl_core::parser;
 
@@ -84,16 +85,7 @@ struct Progress {
     pub total: usize,
 }
 
-/// Runs a Hurl file and returns a result.
-///
-/// # Arguments
-///
-/// * `filename` - Filename of the Hurl file, "-" is used for stdin
-/// * `content` - Content of the Hurl file
-/// * `current_dir` - The current directory of execution (absolute)
-/// * `cli_options` - Options for this run
-/// * `progress` - The progression of this execution
-/// * `logger` - The logger
+/// Runs a Hurl format `content` originated form the file `filename` and returns a result.
 fn execute(
     filename: &str,
     content: &str,
@@ -114,14 +106,18 @@ fn execute(
         Ok(hurl_file) => {
             logger.debug_important("Options:");
             logger.debug(format!("    fail fast: {}", cli_options.fail_fast).as_str());
-            logger.debug(format!("    insecure: {}", cli_options.insecure).as_str());
             logger.debug(format!("    follow redirect: {}", cli_options.follow_location).as_str());
+            logger.debug(format!("    insecure: {}", cli_options.insecure).as_str());
             if let Some(n) = cli_options.max_redirect {
                 logger.debug(format!("    max redirect: {}", n).as_str());
             }
             if let Some(proxy) = &cli_options.proxy {
                 logger.debug(format!("    proxy: {}", proxy).as_str());
             }
+            logger.debug(format!("    retry: {}", cli_options.retry).as_str());
+            if let Some(n) = cli_options.retry_max_count {
+                logger.debug(format!("    retry max count: {}", n).as_str());
+            }
             if !cli_options.variables.is_empty() {
                 logger.debug_important("Variables:");
                 for (name, value) in cli_options.variables.clone() {
@@ -133,73 +129,8 @@ fn execute(
                     format!("Executing {}/{} entries", to_entry, hurl_file.entries.len()).as_str(),
                 );
             }
-            let cacert_file = cli_options.cacert_file.clone();
-            let follow_location = cli_options.follow_location;
-            let verbosity = match (cli_options.verbose, cli_options.very_verbose) {
-                (true, true) => Some(Verbosity::VeryVerbose),
-                (true, _) => Some(Verbosity::Verbose),
-                _ => None,
-            };
-            let insecure = cli_options.insecure;
-            let max_redirect = cli_options.max_redirect;
-            let proxy = cli_options.proxy.clone();
-            let no_proxy = cli_options.no_proxy.clone();
-            let cookie_input_file = cli_options.cookie_input_file.clone();
-            let timeout = cli_options.timeout;
-            let connect_timeout = cli_options.connect_timeout;
-            let user = cli_options.user.clone();
-            let user_agent = cli_options.user_agent.clone();
-            let compressed = cli_options.compressed;
-            let file_root = match cli_options.file_root {
-                Some(ref filename) => Path::new(filename),
-                None => {
-                    if filename == "-" {
-                        current_dir
-                    } else {
-                        let path = Path::new(filename);
-                        path.parent().unwrap()
-                    }
-                }
-            };
-            let context_dir = ContextDir::new(current_dir, file_root);
-
-            let pre_entry = if cli_options.interactive {
-                Some(cli::interactive::pre_entry as fn(Entry) -> bool)
-            } else {
-                None
-            };
-            let post_entry = if cli_options.interactive {
-                Some(cli::interactive::post_entry as fn() -> bool)
-            } else {
-                None
-            };
-            let fail_fast = cli_options.fail_fast;
             let variables = cli_options.variables.clone();
-            let to_entry = cli_options.to_entry;
-            let ignore_asserts = cli_options.ignore_asserts;
-            let very_verbose = cli_options.very_verbose;
-            let runner_options = RunnerOptions {
-                cacert_file,
-                compressed,
-                fail_fast,
-                to_entry,
-                user,
-                context_dir,
-                ignore_asserts,
-                insecure,
-                max_redirect,
-                very_verbose,
-                pre_entry,
-                proxy,
-                post_entry,
-                connect_timeout,
-                cookie_input_file,
-                follow_location,
-                no_proxy,
-                timeout,
-                user_agent,
-                verbosity,
-            };
+            let runner_options = RunnerOptions::from(filename, current_dir, cli_options);
             let mut client = http::Client::new(runner_options.cookie_input_file.clone());
             let result = runner::run(
                 &hurl_file,
@@ -209,7 +140,7 @@ fn execute(
                 &variables,
                 logger,
             );
-            if cli_options.progress {
+            if cli_options.test {
                 logger.test_completed(&result);
             }
             result
@@ -217,12 +148,7 @@ fn execute(
     }
 }
 
-/// Unwraps a result or exit with message.
-///
-/// # Arguments
-///
-/// * result - Something to unwrap
-/// * logger - A logger to log the error
+/// Unwraps a `result` or exit with message.
 fn unwrap_or_exit<T>(result: Result<T, CliError>, code: i32, logger: &BaseLogger) -> T {
     match result {
         Ok(v) => v,
@@ -239,12 +165,14 @@ fn exit_with_error(message: &str, code: i32, logger: &BaseLogger) -> ! {
 }
 /// Executes Hurl entry point.
 fn main() {
+    let libcurl_version = http::libcurl_version_info();
     let version_info = format!(
-        "{} {}",
+        "{} {}\nFeatures (libcurl):  {}\nFeatures (built-in): brotli",
         clap::crate_version!(),
-        http::libcurl_version_info().join(" ")
+        libcurl_version.libraries.join(" "),
+        libcurl_version.features.join(" "),
     );
-    let app = cli::app(version_info.as_str());
+    let mut app = cli::app(&version_info);
     let matches = app.clone().get_matches();
     init_colored();
 
@@ -253,11 +181,11 @@ fn main() {
         || cli::has_flag(&matches, "interactive");
     let color = cli::output_color(&matches);
     let base_logger = BaseLogger::new(color, verbose);
-    let cli_options = cli::parse_options(&matches, &base_logger);
+    let cli_options = cli::parse_options(&matches);
     let cli_options = unwrap_or_exit(cli_options, EXIT_ERROR_UNDEFINED, &base_logger);
 
     let mut filenames = vec![];
-    if let Some(values) = cli::get_strings(&matches, "INPUT") {
+    if let Some(values) = cli::get_strings(&matches, "FILE") {
         for value in values {
             filenames.push(value.to_string());
         }
@@ -267,7 +195,7 @@ fn main() {
     }
 
     if filenames.is_empty() && atty::is(Stream::Stdin) {
-        let error = if app.clone().print_help().is_err() {
+        let error = if app.print_help().is_err() {
             "Panic during printing help"
         } else {
             ""
@@ -312,7 +240,7 @@ fn main() {
         let content = cli::read_to_string(filename);
         let content = unwrap_or_exit(content, EXIT_ERROR_PARSING, &base_logger);
 
-        let progress = if cli_options.progress {
+        let progress = if cli_options.test {
             Some(Progress {
                 current,
                 total: filenames.len(),
@@ -333,25 +261,20 @@ fn main() {
         hurl_results.push(hurl_result.clone());
 
         if matches!(cli_options.output_type, OutputType::ResponseBody)
-            && hurl_result.errors().is_empty()
+            && hurl_result.success
             && !cli_options.interactive
         {
             // By default, we output the body response bytes of the last entry
             if let Some(entry_result) = hurl_result.entries.last() {
-                if let Some(response) = &entry_result.response {
+                if let Some(call) = entry_result.calls.last() {
+                    let response = &call.response;
                     let mut output = vec![];
 
                     // If include options is set, we output the HTTP response headers
                     // with status and version (to mimic curl outputs)
                     if cli_options.include {
-                        let status_line =
-                            format!("HTTP/{} {}\n", response.version, response.status);
-                        output.append(&mut status_line.into_bytes());
-                        for header in response.headers.clone() {
-                            let header_line = format!("{}: {}\n", header.name, header.value);
-                            output.append(&mut header_line.into_bytes());
-                        }
-                        output.append(&mut "\n".to_string().into_bytes());
+                        let text = get_status_line_headers(response, color);
+                        output.append(&mut text.into_bytes());
                     }
                     let mut body = if entry_result.compressed {
                         match response.uncompress_body() {
@@ -427,7 +350,7 @@ fn main() {
         unwrap_or_exit(result, EXIT_ERROR_UNDEFINED, &base_logger);
     }
 
-    if cli_options.summary {
+    if cli_options.test {
         let duration = start.elapsed().as_millis();
         let summary = get_summary(duration, &hurl_results);
         base_logger.info(summary.as_str());
@@ -441,7 +364,7 @@ fn exit_code(hurl_results: &[HurlResult]) -> i32 {
     let mut count_errors_runner = 0;
     let mut count_errors_assert = 0;
     for hurl_result in hurl_results {
-        let errors = hurl_result.clone().errors();
+        let errors = hurl_result.errors();
         if errors.is_empty() {
         } else if errors.iter().filter(|e| !e.assert).count() == 0 {
             count_errors_assert += 1;
@@ -498,7 +421,7 @@ fn write_output(bytes: &Vec<u8>, filename: &Option<String>) -> Result<(), CliErr
         None => write_bytes(bytes.as_slice()),
         Some(filename) => {
             let path = Path::new(filename.as_str());
-            let mut file = match std::fs::File::create(&path) {
+            let mut file = match std::fs::File::create(path) {
                 Err(why) => {
                     return Err(CliError {
                         message: format!("Issue writing to {}: {:?}", path.display(), why),
@@ -525,7 +448,7 @@ fn cookies_output_file(filename: &str, n: usize) -> Result<PathBuf, CliError> {
 }
 
 fn write_cookies_file(file_path: &Path, hurl_results: &[HurlResult]) -> Result<(), CliError> {
-    let mut file = match std::fs::File::create(&file_path) {
+    let mut file = match std::fs::File::create(file_path) {
         Err(why) => {
             return Err(CliError {
                 message: format!("Issue writing to {}: {:?}", file_path.display(), why),
@@ -587,3 +510,25 @@ fn get_summary(duration: u128, hurl_results: &[HurlResult]) -> String {
     s.push_str(format!("Duration:        {} ms\n", duration).as_str());
     s
 }
+
+/// Returns status, version and HTTP headers from an HTTP `response`.
+fn get_status_line_headers(response: &Response, color: bool) -> String {
+    let mut str = String::new();
+    let status_line = format!("HTTP/{} {}\n", response.version, response.status);
+    let status_line = if color {
+        format!("{}", status_line.green().bold())
+    } else {
+        status_line
+    };
+    str.push_str(&status_line);
+    for header in response.headers.iter() {
+        let header_line = if color {
+            format!("{}: {}\n", header.name.cyan().bold(), header.value)
+        } else {
+            format!("{}: {}\n", header.name, header.value)
+        };
+        str.push_str(&header_line);
+    }
+    str.push('\n');
+    str
+}
