@@ -16,71 +16,18 @@
  *
  */
 use std::path::PathBuf;
-use std::time::Duration;
 
 use crate::http;
-use crate::http::ContextDir;
-use hurl_core::ast::{Entry, SourceInfo};
+use hurl_core::ast::SourceInfo;
 
 use super::value::Value;
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub struct RunnerOptions {
-    pub cacert_file: Option<String>,
-    pub compressed: bool,
-    pub connect_timeout: Duration,
-    pub context_dir: ContextDir,
-    pub cookie_input_file: Option<String>,
-    pub fail_fast: bool,
-    pub follow_location: bool,
-    pub ignore_asserts: bool,
-    pub insecure: bool,
-    pub max_redirect: Option<usize>,
-    pub no_proxy: Option<String>,
-    pub post_entry: Option<fn() -> bool>,
-    pub pre_entry: Option<fn(Entry) -> bool>,
-    pub proxy: Option<String>,
-    pub timeout: Duration,
-    pub to_entry: Option<usize>,
-    pub user: Option<String>,
-    pub user_agent: Option<String>,
-    pub verbosity: Option<Verbosity>,
-    pub very_verbose: bool, // If true, log body response in verbose mode.
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum Verbosity {
     Verbose,
     VeryVerbose,
 }
 
-impl Default for RunnerOptions {
-    fn default() -> Self {
-        RunnerOptions {
-            cacert_file: None,
-            compressed: false,
-            connect_timeout: Duration::from_secs(300),
-            context_dir: Default::default(),
-            cookie_input_file: None,
-            fail_fast: false,
-            follow_location: false,
-            ignore_asserts: false,
-            insecure: false,
-            max_redirect: Some(50),
-            no_proxy: None,
-            post_entry: None,
-            pre_entry: None,
-            proxy: None,
-            timeout: Duration::from_secs(300),
-            to_entry: None,
-            user: None,
-            user_agent: None,
-            verbosity: None,
-            very_verbose: false,
-        }
-    }
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct HurlResult {
     pub filename: String,
@@ -91,19 +38,31 @@ pub struct HurlResult {
 }
 
 impl HurlResult {
-    pub fn errors(&self) -> Vec<Error> {
-        self.entries.iter().flat_map(|e| e.errors.clone()).collect()
-    }
-
-    pub fn success(&self) -> bool {
-        self.errors().is_empty()
+    /// Returns all the effective errors of this `HurlResult`.
+    ///
+    /// The errors are only the "effective" ones: those that are due to retry are
+    /// ignored.
+    pub fn errors(&self) -> Vec<&Error> {
+        let mut errors = vec![];
+        let mut next_entries = self.entries.iter().skip(1);
+        for entry in self.entries.iter() {
+            match next_entries.next() {
+                None => errors.extend(&entry.errors),
+                Some(next) => {
+                    if next.entry_index != entry.entry_index {
+                        errors.extend(&entry.errors)
+                    }
+                }
+            }
+        }
+        errors
     }
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct EntryResult {
-    pub request: Option<http::Request>,
-    pub response: Option<http::Response>,
+    pub entry_index: usize,
+    pub calls: Vec<Call>,
     pub captures: Vec<CaptureResult>,
     pub asserts: Vec<AssertResult>,
     pub errors: Vec<Error>,
@@ -111,6 +70,12 @@ pub struct EntryResult {
     pub compressed: bool, // The entry has been executed with `--compressed` option
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct Call {
+    pub request: http::Request,
+    pub response: http::Response,
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub enum AssertResult {
     Version {
@@ -208,8 +173,6 @@ pub enum RunnerError {
     QueryInvalidJson,
     NoQueryResult,
 
-    SubqueryInvalidInput(String),
-
     // Predicate
     PredicateType,
     PredicateValue(Value),
@@ -241,6 +204,11 @@ pub enum RunnerError {
     UnauthorizedFileAccess {
         path: PathBuf,
     },
+
+    // Filter
+    FilterMissingInput {},
+    FilterInvalidInput(String),
+    FilterRegexNoCapture {},
 }
 
 // endregion
