@@ -1,3 +1,20 @@
+/*
+ * Hurl (https://hurl.dev)
+ * Copyright (C) 2022 Orange
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *          http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ *
+ */
 use crate::http::HttpError;
 use crate::runner;
 use crate::runner::RunnerError;
@@ -37,7 +54,6 @@ impl Error for runner::Error {
             RunnerError::QueryInvalidJson { .. } => "Invalid JSON".to_string(),
             RunnerError::QueryInvalidJsonpathExpression { .. } => "Invalid JSONPath".to_string(),
             RunnerError::PredicateType { .. } => "Assert - inconsistent predicate type".to_string(),
-            RunnerError::SubqueryInvalidInput { .. } => "Subquery error".to_string(),
             RunnerError::InvalidDecoding { .. } => "Invalid decoding".to_string(),
             RunnerError::InvalidCharset { .. } => "Invalid charset".to_string(),
             RunnerError::AssertFailure { .. } => "Assert failure".to_string(),
@@ -47,6 +63,9 @@ impl Error for runner::Error {
             RunnerError::CouldNotUncompressResponse(..) => "Decompression error".to_string(),
             RunnerError::InvalidJson { .. } => "Invalid JSON".to_string(),
             RunnerError::UnauthorizedFileAccess { .. } => "Unauthorized file access".to_string(),
+            RunnerError::FilterMissingInput { .. } => "Filter Error".to_string(),
+            RunnerError::FilterInvalidInput { .. } => "Filter Error".to_string(),
+            RunnerError::FilterRegexNoCapture { .. } => "Filter Error".to_string(),
         }
     }
 
@@ -98,9 +117,6 @@ impl Error for runner::Error {
             RunnerError::PredicateType { .. } => {
                 "predicate type inconsistent with value return by query".to_string()
             }
-            RunnerError::SubqueryInvalidInput(t) => {
-                format!("type <{}> from query result and subquery do not match", t)
-            }
             RunnerError::InvalidDecoding { charset } => {
                 format!("the body can not be decoded with charset '{}'", charset)
             }
@@ -142,6 +158,13 @@ impl Error for runner::Error {
                     path.to_str().unwrap()
                 )
             }
+            RunnerError::FilterMissingInput { .. } => {
+                "Missing value to apply the filter".to_string()
+            }
+            RunnerError::FilterInvalidInput(message) => {
+                format!("Invalid Filter Input <{}>", message)
+            }
+            RunnerError::FilterRegexNoCapture { .. } => "Capture not found".to_string(),
         }
     }
 }
@@ -172,6 +195,7 @@ impl From<HttpError> for RunnerError {
             HttpError::UnsupportedContentEncoding { description } => {
                 RunnerError::UnsupportedContentEncoding(description)
             }
+            HttpError::InvalidUrl(url) => RunnerError::InvalidUrl(url),
         }
     }
 }
