@@ -24,10 +24,10 @@
 //!
 
 pub use self::core::{
-    AssertResult, CaptureResult, EntryResult, Error, HurlResult, RunnerError, RunnerOptions,
-    Verbosity,
+    AssertResult, Call, CaptureResult, EntryResult, Error, HurlResult, RunnerError, Verbosity,
 };
 pub use self::hurl_file::run;
+pub use self::runner_options::RunnerOptions;
 pub use self::value::Value;
 
 mod assert;
@@ -37,6 +37,7 @@ mod core;
 mod entry;
 mod error;
 mod expr;
+mod filter;
 mod hurl_file;
 mod json;
 mod multipart;
@@ -45,7 +46,7 @@ mod predicate_value;
 mod query;
 mod request;
 mod response;
-mod subquery;
+mod runner_options;
 mod template;
 mod value;
 mod xpath;
