@@ -25,7 +25,6 @@ use super::value::Value;
 use super::xpath;
 use crate::http;
 use crate::jsonpath;
-use crate::runner::subquery::eval_subquery;
 use hurl_core::ast::*;
 use sha2::Digest;
 
@@ -35,29 +34,10 @@ pub fn eval_query(
     query: &Query,
     variables: &HashMap<String, Value>,
     http_response: &http::Response,
-) -> QueryResult {
-    let value = eval_query_value(query, variables, http_response)?;
-    if let Some((_, subquery)) = &query.subquery {
-        if let Some(value) = &value {
-            eval_subquery(subquery, value, variables)
-        } else {
-            Err(Error {
-                source_info: subquery.source_info.clone(),
-                inner: RunnerError::SubqueryInvalidInput("none".to_string()),
-                assert: false,
-            })
-        }
-    } else {
-        Ok(value)
-    }
-}
-pub fn eval_query_value(
-    query: &Query,
-    variables: &HashMap<String, Value>,
-    http_response: &http::Response,
 ) -> QueryResult {
     match query.value.clone() {
         QueryValue::Status {} => Ok(Some(Value::Integer(i64::from(http_response.status)))),
+        QueryValue::Url {} => Ok(Some(Value::String(http_response.url.clone()))),
         QueryValue::Header { name, .. } => {
             let header_name = eval_template(&name, variables)?;
             let values = http_response.get_header_values(&header_name);
@@ -354,7 +334,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 7, 1, 10),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -376,7 +355,6 @@ pub mod tests {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -398,7 +376,6 @@ pub mod tests {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -420,6 +397,7 @@ pub mod tests {
                 .to_string(),
             ),
             duration: Default::default(),
+            url: "".to_string(),
         }
     }
 
@@ -442,7 +420,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 10, 1, 19),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -465,39 +442,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 10, 1, 18),
                 },
             },
-            subquery: None,
-        }
-    }
-
-    pub fn jsonpath_errors_count() -> Query {
-        // jsonpath "$.errors" count
-        Query {
-            source_info: SourceInfo::new(1, 1, 1, 19),
-            value: QueryValue::Jsonpath {
-                space0: Whitespace {
-                    value: String::from(""),
-                    source_info: SourceInfo::new(1, 9, 1, 10),
-                },
-                expr: Template {
-                    elements: vec![TemplateElement::String {
-                        value: String::from("$.errors"),
-                        encoded: String::from("$.errors"),
-                    }],
-                    quotes: true,
-                    //   delimiter: "".to_string(),
-                    source_info: SourceInfo::new(1, 10, 1, 18),
-                },
-            },
-            subquery: Some((
-                Whitespace {
-                    value: "".to_string(),
-                    source_info: SourceInfo::new(0, 0, 0, 0),
-                },
-                Subquery {
-                    source_info: SourceInfo::new(0, 0, 0, 0),
-                    value: SubqueryValue::Count {},
-                },
-            )),
         }
     }
 
@@ -520,7 +464,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 10, 1, 18),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -542,7 +485,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 7, 1, 26),
                 }),
             },
-            subquery: None,
         }
     }
 
@@ -564,7 +506,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 7, 1, 10),
                 }),
             },
-            subquery: None,
         }
     }
 
@@ -576,7 +517,6 @@ pub mod tests {
                 &Query {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                     value: QueryValue::Status {},
-                    subquery: None
                 },
                 &variables,
                 &http::hello_http_response(),
@@ -607,7 +547,6 @@ pub mod tests {
                     source_info: SourceInfo::new(2, 8, 2, 14),
                 },
             },
-            subquery: None,
         };
         //    let error = query_header.eval(http::hello_http_response()).err().unwrap();
         //    assert_eq!(error.source_info.start, Pos { line: 1, column: 8 });
@@ -638,7 +577,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 8, 1, 16),
                 },
             },
-            subquery: None,
         };
         assert_eq!(
             eval_query(&query_header, &variables, &http::hello_http_response())
@@ -666,6 +604,7 @@ pub mod tests {
             ],
             body: vec![],
             duration: Default::default(),
+            url: "".to_string(),
         };
 
         // cookie "LSID"
@@ -685,7 +624,6 @@ pub mod tests {
                     attribute: None,
                 },
             },
-            subquery: None,
         };
         assert_eq!(
             eval_query(&query, &variables, &response.clone())
@@ -715,7 +653,6 @@ pub mod tests {
                     }),
                 },
             },
-            subquery: None,
         };
         assert_eq!(
             eval_query(&query, &variables, &response.clone())
@@ -745,7 +682,6 @@ pub mod tests {
                     }),
                 },
             },
-            subquery: None,
         };
         assert_eq!(
             eval_query(&query, &variables, &response.clone())
@@ -775,7 +711,6 @@ pub mod tests {
                     }),
                 },
             },
-            subquery: None,
         };
         assert_eq!(eval_query(&query, &variables, &response).unwrap(), None);
     }
@@ -866,7 +801,6 @@ pub mod tests {
                 &Query {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                     value: QueryValue::Body {},
-                    subquery: None
                 },
                 &variables,
                 &http::hello_http_response(),
@@ -879,7 +813,6 @@ pub mod tests {
             &Query {
                 source_info: SourceInfo::new(1, 1, 1, 2),
                 value: QueryValue::Body {},
-                subquery: None,
             },
             &variables,
             &http::bytes_http_response(),
@@ -904,6 +837,7 @@ pub mod tests {
             headers: vec![],
             body: vec![200],
             duration: Default::default(),
+            url: "".to_string(),
         };
         let error = eval_query(&xpath_users(), &variables, &http_response)
             .err()
@@ -937,7 +871,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 7, 1, 10),
                 },
             },
-            subquery: None,
         };
         let error = eval_query(&query, &variables, &http::xml_two_users_http_response())
             .err()
@@ -992,7 +925,6 @@ pub mod tests {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -1003,7 +935,7 @@ pub mod tests {
             eval_query(
                 &xpath_html_charset(),
                 &variables,
-                &http::html_http_response()
+                &http::html_http_response(),
             )
             .unwrap()
             .unwrap(),
@@ -1033,7 +965,6 @@ pub mod tests {
                     source_info: SourceInfo::new(1, 10, 1, 13),
                 },
             },
-            subquery: None,
         };
 
         let error = eval_query(&jsonpath_query, &variables, &json_http_response())
@@ -1063,6 +994,7 @@ pub mod tests {
             headers: vec![],
             body: String::into_bytes(String::from("xxx")),
             duration: Default::default(),
+            url: "".to_string(),
         };
         let error = eval_query(&jsonpath_success(), &variables, &http_response)
             .err()
@@ -1080,6 +1012,7 @@ pub mod tests {
             headers: vec![],
             body: String::into_bytes(String::from("{}")),
             duration: Default::default(),
+            url: "".to_string(),
         };
         //assert_eq!(jsonpath_success().eval(http_response).unwrap(), Value::List(vec![]));
         assert_eq!(
@@ -1112,13 +1045,6 @@ pub mod tests {
                 )])
             ])
         );
-
-        assert_eq!(
-            eval_query(&jsonpath_errors_count(), &variables, &json_http_response())
-                .unwrap()
-                .unwrap(),
-            Value::Integer(2)
-        );
     }
 
     #[test]
@@ -1146,7 +1072,6 @@ pub mod tests {
                 &Query {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                     value: QueryValue::Bytes {},
-                    subquery: None
                 },
                 &variables,
                 &http::hello_http_response(),
@@ -1165,7 +1090,6 @@ pub mod tests {
                 &Query {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                     value: QueryValue::Sha256 {},
-                    subquery: None
                 },
                 &variables,
                 &http::Response {
@@ -1174,7 +1098,8 @@ pub mod tests {
                     headers: vec![],
                     body: vec![0xff],
                     duration: Default::default(),
-                },
+                    url: "".to_string()
+                }
             )
             .unwrap()
             .unwrap(),
