@@ -16,9 +16,9 @@
  *
  */
 use std::collections::HashMap;
-use std::path::Path;
 
 use crate::http;
+use crate::http::ContextDir;
 use hurl_core::ast::*;
 
 use super::assert::eval_assert;
@@ -29,11 +29,19 @@ use super::json::eval_json_value;
 use super::template::eval_template;
 use super::value::Value;
 
+/// Returns a list of response assert results.
+///
+/// # Arguments
+///
+/// * `response` - The spec HTTP response
+/// * `variables` - A map of input variables
+/// * `http_response` - The actual HTTP response
+/// * `context_dir` - The context directory for files
 pub fn eval_asserts(
-    response: Response,
+    response: &Response,
     variables: &HashMap<String, Value>,
-    http_response: http::Response,
-    context_dir: &Path,
+    http_response: &http::Response,
+    context_dir: &ContextDir,
 ) -> Vec<AssertResult> {
     let mut asserts = vec![];
 
@@ -63,17 +71,17 @@ pub fn eval_asserts(
                 });
             }
             Ok(expected) => {
-                let header_name = header.key.value.clone();
-                let actuals = http_response.get_header(header_name);
+                let header_name = &header.key.value;
+                let actuals = http_response.get_header_values(header_name);
                 if actuals.is_empty() {
                     asserts.push(AssertResult::Header {
                         actual: Err(Error {
-                            source_info: header.key.clone().source_info,
+                            source_info: header.key.source_info.clone(),
                             inner: RunnerError::QueryHeaderNotFound {},
                             assert: false,
                         }),
                         expected,
-                        source_info: header.key.clone().source_info,
+                        source_info: header.key.source_info.clone(),
                     });
                 } else if actuals.len() == 1 {
                     let actual = actuals.first().unwrap().to_string();
@@ -110,128 +118,183 @@ pub fn eval_asserts(
         }
     }
 
-    // implicit assert on body
-    if let Some(body) = response.clone().body {
-        match body.value {
-            Bytes::Json { value } => {
-                let expected = match eval_json_value(value, variables) {
-                    Ok(s) => Ok(Value::String(s)),
-                    Err(e) => Err(e),
-                };
-                let actual = match http_response.text() {
-                    Ok(s) => Ok(Value::String(s)),
-                    Err(e) => Err(Error {
-                        source_info: SourceInfo {
-                            start: body.space0.source_info.end.clone(),
-                            end: body.space0.source_info.end.clone(),
-                        },
-                        inner: e,
-                        assert: true,
-                    }),
-                };
-                asserts.push(AssertResult::Body {
-                    actual,
-                    expected,
-                    source_info: body.space0.source_info.clone(),
-                })
-            }
-            Bytes::Xml { value } => {
-                let expected = Ok(Value::String(value));
-                let actual = match http_response.text() {
-                    Ok(s) => Ok(Value::String(s)),
-                    Err(e) => Err(Error {
-                        source_info: SourceInfo {
-                            start: body.space0.source_info.end.clone(),
-                            end: body.space0.source_info.end.clone(),
-                        },
-                        inner: e,
-                        assert: true,
-                    }),
-                };
-                asserts.push(AssertResult::Body {
-                    actual,
-                    expected,
-                    source_info: body.space0.source_info.clone(),
-                })
-            }
-            Bytes::RawString(RawString { value, .. }) => {
-                let expected = match eval_template(&value, variables) {
-                    Ok(s) => Ok(Value::String(s)),
-                    Err(e) => Err(e),
-                };
-                let actual = match http_response.text() {
-                    Ok(s) => Ok(Value::String(s)),
-                    Err(e) => Err(Error {
-                        source_info: SourceInfo {
-                            start: body.space0.source_info.end.clone(),
-                            end: body.space0.source_info.end.clone(),
-                        },
-                        inner: e,
-                        assert: true,
-                    }),
-                };
-                asserts.push(AssertResult::Body {
-                    actual,
-                    expected,
-                    source_info: value.source_info,
-                })
-            }
-            Bytes::Base64(Base64 {
-                value,
-                space0,
-                space1,
-                ..
-            }) => asserts.push(AssertResult::Body {
-                actual: Ok(Value::Bytes(http_response.body.clone())),
-                expected: Ok(Value::Bytes(value)),
-                source_info: SourceInfo {
-                    start: space0.source_info.end,
-                    end: space1.source_info.start,
-                },
-            }),
-            Bytes::Hex(Hex {
-                value,
-                space0,
-                space1,
-                ..
-            }) => asserts.push(AssertResult::Body {
-                actual: Ok(Value::Bytes(http_response.body.clone())),
-                expected: Ok(Value::Bytes(value)),
-                source_info: SourceInfo {
-                    start: space0.source_info.end,
-                    end: space1.source_info.start,
-                },
-            }),
-            Bytes::File { .. } => {
-                let expected = match eval_body(body.clone(), variables, context_dir) {
-                    Ok(body) => Ok(Value::Bytes(body.bytes())),
-                    Err(e) => Err(e),
-                };
-                let actual = Ok(Value::Bytes(http_response.body.clone()));
-                asserts.push(AssertResult::Body {
-                    actual,
-                    expected,
-                    source_info: body.space0.source_info.clone(),
-                })
-            }
-        };
+    if let Some(body) = &response.body {
+        let assert = eval_implicit_body_asserts(body, variables, http_response, context_dir);
+        asserts.push(assert);
     }
 
-    for assert in response.asserts() {
-        let assert_result = eval_assert(assert, variables, http_response.clone());
+    for assert in response.asserts().iter() {
+        let assert_result = eval_assert(assert, variables, http_response);
         asserts.push(assert_result);
     }
     asserts
 }
 
+/// Check the body of an actual HTTP response against a spec body.
+///
+/// # Arguments
+///
+/// * `spec_body` - The spec HTTP response body
+/// * `variables` - A map of input variables
+/// * `http_response` - The actual HTTP response
+/// * `context_dir` - The context directory for files
+fn eval_implicit_body_asserts(
+    spec_body: &Body,
+    variables: &HashMap<String, Value>,
+    http_response: &http::Response,
+    context_dir: &ContextDir,
+) -> AssertResult {
+    match &spec_body.value {
+        Bytes::Json { value } => {
+            let expected = match eval_json_value(value, variables) {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(e),
+            };
+            let actual = match http_response.text() {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: spec_body.space0.source_info.clone(),
+            }
+        }
+        Bytes::Xml { value } => {
+            let expected = Ok(Value::String(value.to_string()));
+            let actual = match http_response.text() {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: spec_body.space0.source_info.clone(),
+            }
+        }
+        Bytes::RawString(RawString { value, .. }) => {
+            let expected = match eval_template(value, variables) {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(e),
+            };
+            let actual = match http_response.text() {
+                Ok(s) => Ok(Value::String(s)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: value.source_info.clone(),
+            }
+        }
+        Bytes::Base64(Base64 {
+            value,
+            space0,
+            space1,
+            ..
+        }) => {
+            let expected = Ok(Value::Bytes(value.to_vec()));
+            let actual = match http_response.uncompress_body() {
+                Ok(b) => Ok(Value::Bytes(b)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: SourceInfo {
+                    start: space0.source_info.end.clone(),
+                    end: space1.source_info.start.clone(),
+                },
+            }
+        }
+        Bytes::Hex(Hex {
+            value,
+            space0,
+            space1,
+            ..
+        }) => {
+            let expected = Ok(Value::Bytes(value.to_vec()));
+            let actual = match http_response.uncompress_body() {
+                Ok(b) => Ok(Value::Bytes(b)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: SourceInfo {
+                    start: space0.source_info.end.clone(),
+                    end: space1.source_info.start.clone(),
+                },
+            }
+        }
+        Bytes::File { .. } => {
+            let expected = match eval_body(spec_body, variables, context_dir) {
+                Ok(body) => Ok(Value::Bytes(body.bytes())),
+                Err(e) => Err(e),
+            };
+            let actual = match http_response.uncompress_body() {
+                Ok(b) => Ok(Value::Bytes(b)),
+                Err(e) => Err(Error {
+                    source_info: SourceInfo {
+                        start: spec_body.space0.source_info.end.clone(),
+                        end: spec_body.space0.source_info.end.clone(),
+                    },
+                    inner: RunnerError::from(e),
+                    assert: true,
+                }),
+            };
+            AssertResult::Body {
+                actual,
+                expected,
+                source_info: spec_body.space0.source_info.clone(),
+            }
+        }
+    }
+}
+
 pub fn eval_captures(
-    response: Response,
+    response: &Response,
     http_response: &http::Response,
     variables: &HashMap<String, Value>,
 ) -> Result<Vec<CaptureResult>, Error> {
     let mut captures = vec![];
-    for capture in response.captures() {
-        let capture_result = eval_capture(capture, variables, http_response.clone())?;
+    for capture in response.captures().iter() {
+        let capture_result = eval_capture(capture, variables, http_response)?;
         captures.push(capture_result);
     }
     Ok(captures)
@@ -247,7 +310,7 @@ mod tests {
     pub fn user_response() -> Response {
         let whitespace = Whitespace {
             value: String::from(" "),
-            source_info: SourceInfo::init(1, 1, 1, 1),
+            source_info: SourceInfo::new(1, 1, 1, 1),
         };
         let line_terminator = LineTerminator {
             space0: whitespace.clone(),
@@ -259,12 +322,12 @@ mod tests {
             line_terminators: vec![],
             version: Version {
                 value: VersionValue::Version1,
-                source_info: SourceInfo::init(2, 6, 2, 9),
+                source_info: SourceInfo::new(2, 6, 2, 9),
             },
             space0: whitespace.clone(),
             status: Status {
                 value: StatusValue::Specific(200),
-                source_info: SourceInfo::init(2, 10, 2, 13),
+                source_info: SourceInfo::new(2, 10, 2, 13),
             },
             space1: whitespace.clone(),
             line_terminator0: line_terminator.clone(),
@@ -275,48 +338,48 @@ mod tests {
                     space0: whitespace.clone(),
                     line_terminator0: line_terminator.clone(),
                     value: SectionValue::Asserts(vec![assert::tests::assert_count_user()]),
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
                 Section {
                     line_terminators: vec![],
                     space0: whitespace,
                     line_terminator0: line_terminator,
                     value: SectionValue::Captures(vec![capture::tests::user_count_capture()]),
-                    source_info: SourceInfo::init(0, 0, 0, 0),
+                    source_info: SourceInfo::new(0, 0, 0, 0),
                 },
             ],
             body: None,
-            source_info: SourceInfo::init(0, 0, 0, 0),
+            source_info: SourceInfo::new(0, 0, 0, 0),
         }
     }
 
     #[test]
     pub fn test_eval_asserts() {
         let variables = HashMap::new();
-        let context_dir = Path::new("");
+        let context_dir = ContextDir::default();
         assert_eq!(
             eval_asserts(
-                user_response(),
+                &user_response(),
                 &variables,
-                http::xml_two_users_http_response(),
-                context_dir,
+                &http::xml_two_users_http_response(),
+                &context_dir,
             ),
             vec![
                 AssertResult::Version {
                     actual: String::from("1.0"),
                     expected: String::from("1.0"),
-                    source_info: SourceInfo::init(2, 6, 2, 9),
+                    source_info: SourceInfo::new(2, 6, 2, 9),
                 },
                 AssertResult::Status {
                     actual: 200,
                     expected: 200,
-                    source_info: SourceInfo::init(2, 10, 2, 13),
+                    source_info: SourceInfo::new(2, 10, 2, 13),
                 },
                 AssertResult::Explicit {
                     actual: Ok(Some(Value::Nodeset(2))),
-                    source_info: SourceInfo::init(1, 14, 1, 27),
+                    source_info: SourceInfo::new(1, 14, 1, 27),
                     predicate_result: Some(Err(Error {
-                        source_info: SourceInfo::init(1, 0, 1, 0),
+                        source_info: SourceInfo::new(1, 0, 1, 0),
                         inner: RunnerError::AssertFailure {
                             actual: "2".to_string(),
                             expected: "3".to_string(),
@@ -324,7 +387,7 @@ mod tests {
                         },
                         assert: true,
                     })),
-                }
+                },
             ]
         );
     }
@@ -334,7 +397,7 @@ mod tests {
         let variables = HashMap::new();
         assert_eq!(
             eval_captures(
-                user_response(),
+                &user_response(),
                 &http::xml_two_users_http_response(),
                 &variables,
             )
