@@ -19,6 +19,7 @@
 use crate::runner::{HurlResult, Value};
 use colored::*;
 use hurl_core::error::Error;
+use std::cmp::max;
 
 /// A simple logger to log app related event (start, high levels error, etc...).
 /// When we run an [`hurl_core::ast::HurlFile`], user has to provide a dedicated Hurl logger (see [`Logger`]).
@@ -46,13 +47,13 @@ impl BaseLogger {
             },
             (true, false) => BaseLogger {
                 info: log_info,
-                debug: nop1,
+                debug: |_| {},
                 warning: log_warning,
                 error: log_error,
             },
             (false, false) => BaseLogger {
                 info: log_info,
-                debug: nop1,
+                debug: |_| {},
                 warning: log_warning_no_color,
                 error: log_error_no_color,
             },
@@ -82,14 +83,16 @@ impl BaseLogger {
 pub struct Logger<'a> {
     pub info: fn(&str),
     pub debug: fn(&str),
+    pub debug_curl: fn(&str),
+    pub debug_error: fn(&str, &str, &dyn Error),
+    pub debug_header_in: fn(&str, &str),
+    pub debug_header_out: fn(&str, &str),
     pub debug_important: fn(&str),
+    pub debug_method_version_out: fn(&str),
+    pub debug_status_version_in: fn(&str),
     pub warning: fn(&str),
     pub error: fn(&str),
     pub error_rich: fn(&str, &str, &dyn Error),
-    pub method_version_out: fn(&str),
-    pub status_version_in: fn(&str),
-    pub header_in: fn(&str, &str),
-    pub header_out: fn(&str, &str),
     pub capture: fn(&str, &Value),
     pub test_running: fn(&str, usize, usize),
     pub test_completed: fn(result: &HurlResult),
@@ -106,15 +109,17 @@ impl<'a> Logger<'a> {
             (true, true) => Logger {
                 info: log_info,
                 debug: log_debug,
+                debug_curl: log_debug_curl,
+                debug_error: log_debug_error,
+                debug_header_in: log_debug_header_in,
+                debug_header_out: log_debug_header_out,
                 debug_important: log_debug_important,
+                debug_method_version_out: log_debug_method_version_out,
+                debug_status_version_in: log_debug_status_version_in,
                 warning: log_warning,
                 error: log_error,
                 error_rich: log_error_rich,
-                method_version_out: log_method_version_out,
-                status_version_in: log_status_version_in,
                 capture: log_capture,
-                header_in: log_header_in,
-                header_out: log_header_out,
                 test_running: log_test_running,
                 test_completed: log_test_completed,
                 color,
@@ -125,15 +130,17 @@ impl<'a> Logger<'a> {
             (false, true) => Logger {
                 info: log_info,
                 debug: log_debug_no_color,
+                debug_curl: log_debug_curl_no_color,
+                debug_error: log_debug_error_no_color,
+                debug_header_in: log_debug_header_in_no_color,
+                debug_header_out: log_debug_header_out_no_color,
                 debug_important: log_debug_no_color,
+                debug_method_version_out: log_debug_method_version_out_no_color,
+                debug_status_version_in: log_debug_status_version_in_no_color,
                 warning: log_warning_no_color,
                 error: log_error_no_color,
                 error_rich: log_error_rich_no_color,
-                method_version_out: log_method_version_out_no_color,
-                status_version_in: log_status_version_in_no_color,
                 capture: log_capture_no_color,
-                header_in: log_header_in_no_color,
-                header_out: log_header_out_no_color,
                 test_running: log_test_running_no_color,
                 test_completed: log_test_completed_no_color,
                 color,
@@ -143,16 +150,18 @@ impl<'a> Logger<'a> {
             },
             (true, false) => Logger {
                 info: log_info,
-                debug: nop1,
-                debug_important: nop1,
+                debug: |_| {},
+                debug_curl: |_| {},
+                debug_error: |_, _, _| {},
+                debug_header_in: |_, _| {},
+                debug_header_out: |_, _| {},
+                debug_important: |_| {},
+                debug_method_version_out: |_| {},
+                debug_status_version_in: |_| {},
                 warning: log_warning,
                 error: log_error,
                 error_rich: log_error_rich,
-                method_version_out: nop1,
-                status_version_in: nop1,
-                capture: nop3,
-                header_in: nop2,
-                header_out: nop2,
+                capture: |_, _| {},
                 test_running: log_test_running,
                 test_completed: log_test_completed,
                 color,
@@ -162,16 +171,18 @@ impl<'a> Logger<'a> {
             },
             (false, false) => Logger {
                 info: log_info,
-                debug: nop1,
-                debug_important: nop1,
+                debug: |_| {},
+                debug_curl: |_| {},
+                debug_error: |_, _, _| {},
+                debug_header_in: |_, _| {},
+                debug_header_out: |_, _| {},
+                debug_important: |_| {},
+                debug_method_version_out: |_| {},
+                debug_status_version_in: |_| {},
                 warning: log_warning_no_color,
                 error: log_error_no_color,
                 error_rich: log_error_rich_no_color,
-                method_version_out: nop1,
-                status_version_in: nop1,
-                capture: nop3,
-                header_in: nop2,
-                header_out: nop2,
+                capture: |_, _| {},
                 test_running: log_test_running_no_color,
                 test_completed: log_test_completed_no_color,
                 color,
@@ -190,10 +201,30 @@ impl<'a> Logger<'a> {
         (self.debug)(message)
     }
 
+    pub fn debug_curl(&self, message: &str) {
+        (self.debug_curl)(message)
+    }
+
+    pub fn debug_error(&self, error: &dyn Error) {
+        (self.debug_error)(self.filename, self.content, error)
+    }
+
+    pub fn debug_header_in(&self, name: &str, value: &str) {
+        (self.debug_header_in)(name, value)
+    }
+
+    pub fn debug_header_out(&self, name: &str, value: &str) {
+        (self.debug_header_out)(name, value)
+    }
+
     pub fn debug_important(&self, message: &str) {
         (self.debug_important)(message)
     }
 
+    pub fn debug_status_version_in(&self, line: &str) {
+        (self.debug_status_version_in)(line)
+    }
+
     pub fn warning(&self, message: &str) {
         (self.warning)(message)
     }
@@ -207,25 +238,13 @@ impl<'a> Logger<'a> {
     }
 
     pub fn method_version_out(&self, line: &str) {
-        (self.method_version_out)(line)
-    }
-
-    pub fn status_version_in(&self, line: &str) {
-        (self.status_version_in)(line)
+        (self.debug_method_version_out)(line)
     }
 
     pub fn capture(&self, name: &str, value: &Value) {
         (self.capture)(name, value)
     }
 
-    pub fn header_in(&self, name: &str, value: &str) {
-        (self.header_in)(name, value)
-    }
-
-    pub fn header_out(&self, name: &str, value: &str) {
-        (self.header_out)(name, value)
-    }
-
     pub fn test_running(&self, current: usize, total: usize) {
         (self.test_running)(self.filename, current, total)
     }
@@ -235,12 +254,6 @@ impl<'a> Logger<'a> {
     }
 }
 
-fn nop1(_one: &str) {}
-
-fn nop2(_one: &str, _two: &str) {}
-
-fn nop3(_one: &str, _two: &Value) {}
-
 fn log_info(message: &str) {
     eprintln!("{}", message);
 }
@@ -261,6 +274,22 @@ fn log_debug_no_color(message: &str) {
     }
 }
 
+fn log_debug_curl(message: &str) {
+    if message.is_empty() {
+        eprintln!("{}", "**".blue().bold());
+    } else {
+        eprintln!("{} {}", "**".blue().bold(), message.green());
+    }
+}
+
+fn log_debug_curl_no_color(message: &str) {
+    if message.is_empty() {
+        eprintln!("**");
+    } else {
+        eprintln!("** {}", message);
+    }
+}
+
 fn log_debug_important(message: &str) {
     if message.is_empty() {
         eprintln!("{}", "*".blue().bold());
@@ -269,8 +298,52 @@ fn log_debug_important(message: &str) {
     }
 }
 
+fn log_debug_error(filename: &str, content: &str, error: &dyn Error) {
+    let message = error_string(filename, content, error, true);
+    get_lines(&message).iter().for_each(|l| log_debug(l));
+}
+
+fn log_debug_error_no_color(filename: &str, content: &str, error: &dyn Error) {
+    let message = error_string(filename, content, error, false);
+    get_lines(&message)
+        .iter()
+        .for_each(|l| log_debug_no_color(l));
+}
+
+fn log_debug_header_in(name: &str, value: &str) {
+    eprintln!("< {}: {}", name.cyan().bold(), value)
+}
+
+fn log_debug_header_in_no_color(name: &str, value: &str) {
+    eprintln!("< {}: {}", name, value)
+}
+
+fn log_debug_header_out(name: &str, value: &str) {
+    eprintln!("> {}: {}", name.cyan().bold(), value)
+}
+
+fn log_debug_header_out_no_color(name: &str, value: &str) {
+    eprintln!("> {}: {}", name, value)
+}
+
+fn log_debug_method_version_out(line: &str) {
+    eprintln!("> {}", line.purple().bold())
+}
+
+fn log_debug_method_version_out_no_color(line: &str) {
+    eprintln!("> {}", line)
+}
+
+fn log_debug_status_version_in(line: &str) {
+    eprintln!("< {}", line.green().bold())
+}
+
+fn log_debug_status_version_in_no_color(line: &str) {
+    eprintln!("< {}", line)
+}
+
 fn log_warning(message: &str) {
-    eprintln!("{}: {}", "warning".yellow().bold(), message);
+    eprintln!("{}: {}", "warning".yellow().bold(), message.bold());
 }
 
 fn log_warning_no_color(message: &str) {
@@ -295,22 +368,6 @@ fn log_error_rich_no_color(filename: &str, content: &str, error: &dyn Error) {
     eprintln!("error: {}\n", &message)
 }
 
-fn log_method_version_out(line: &str) {
-    eprintln!("> {}", line.purple().bold())
-}
-
-fn log_method_version_out_no_color(line: &str) {
-    eprintln!("> {}", line)
-}
-
-fn log_status_version_in(line: &str) {
-    eprintln!("< {}", line.green().bold())
-}
-
-fn log_status_version_in_no_color(line: &str) {
-    eprintln!("< {}", line)
-}
-
 fn log_capture(name: &str, value: &Value) {
     eprintln!("{} {}: {}", "*".blue().bold(), name.yellow().bold(), value)
 }
@@ -319,22 +376,6 @@ fn log_capture_no_color(name: &str, value: &Value) {
     eprintln!("* {}: {}", name, value)
 }
 
-fn log_header_in(name: &str, value: &str) {
-    eprintln!("< {}: {}", name.cyan().bold(), value)
-}
-
-fn log_header_in_no_color(name: &str, value: &str) {
-    eprintln!("< {}: {}", name, value)
-}
-
-fn log_header_out(name: &str, value: &str) {
-    eprintln!("> {}: {}", name.cyan().bold(), value)
-}
-
-fn log_header_out_no_color(name: &str, value: &str) {
-    eprintln!("> {}: {}", name, value)
-}
-
 fn log_test_running(filename: &str, current: usize, total: usize) {
     eprintln!(
         "{}: {} [{}/{}]",
@@ -355,11 +396,7 @@ fn log_test_completed(result: &HurlResult) {
     } else {
         "Failure".red().bold()
     };
-    let count = result
-        .entries
-        .iter()
-        .filter(|r| r.request.is_some())
-        .count();
+    let count = result.entries.iter().flat_map(|r| &r.calls).count();
     eprintln!(
         "{}: {} ({} request(s) in {} ms)",
         result.filename.bold(),
@@ -371,11 +408,7 @@ fn log_test_completed(result: &HurlResult) {
 
 fn log_test_completed_no_color(result: &HurlResult) {
     let state = if result.success { "Success" } else { "Failure" };
-    let count = result
-        .entries
-        .iter()
-        .filter(|r| r.request.is_some())
-        .count();
+    let count = result.entries.iter().flat_map(|r| &r.calls).count();
     eprintln!(
         "{}: {} ({} request(s) in {} ms)",
         result.filename, state, count, result.time_in_ms
@@ -388,23 +421,13 @@ pub fn error_string_no_color(filename: &str, content: &str, error: &dyn Error) -
 
 /// Returns an `error` as a string, given `lines` of content and a `filename`.
 fn error_string(filename: &str, content: &str, error: &dyn Error, colored: bool) -> String {
-    let lines: Vec<&str> = regex::Regex::new(r"\n|\r\n")
-        .unwrap()
-        .split(content)
-        .collect();
-
-    let line_number_size = if lines.len() < 100 {
-        2
-    } else if lines.len() < 1000 {
-        3
+    let lines = get_lines(content);
+    let line_number_size = max(lines.len().to_string().len(), 2);
+    let arrow = if colored {
+        "-->".blue().bold().to_string()
     } else {
-        4
+        "-->".to_string()
     };
-
-    let mut arrow = "-->".to_string();
-    if colored {
-        arrow = arrow.blue().bold().to_string()
-    }
     let line_number = error.source_info().start.line;
     let column_number = error.source_info().start.column;
 
@@ -419,10 +442,11 @@ fn error_string(filename: &str, content: &str, error: &dyn Error, colored: bool)
 
     let line = lines.get(line_number - 1).unwrap();
     let line = str::replace(line, "\t", "    "); // replace all your tabs with 4 characters
-    let mut separator = "|".to_string();
-    if colored {
-        separator = separator.blue().bold().to_string()
-    }
+    let separator = if colored {
+        "|".blue().bold().to_string()
+    } else {
+        "|".to_string()
+    };
 
     // TODO: to clean/Refacto
     // specific case for assert errors
@@ -505,8 +529,7 @@ fn error_string(filename: &str, content: &str, error: &dyn Error, colored: bool)
 }
 
 fn add_line_prefix(s: &str, prefix: &str, colored: bool) -> String {
-    let lines: Vec<&str> = regex::Regex::new(r"\n|\r\n").unwrap().split(s).collect();
-    lines
+    get_lines(s)
         .iter()
         .map(|line| {
             if colored {
@@ -519,6 +542,10 @@ fn add_line_prefix(s: &str, prefix: &str, colored: bool) -> String {
         .join("\n")
 }
 
+fn get_lines(text: &str) -> Vec<&str> {
+    regex::Regex::new(r"\n|\r\n").unwrap().split(text).collect()
+}
+
 #[cfg(test)]
 pub mod tests {
     use super::*;
