@@ -358,13 +358,16 @@ fn test_form_params() {
 
 #[test]
 fn test_redirect() {
-    let request_spec = default_get_request("http://localhost:8000/redirect");
+    let request_spec = default_get_request("http://localhost:8000/redirect-absolute");
     let logger = Logger::new(false, false, "", "");
     let options = ClientOptions::default();
     let mut client = Client::new(None);
     let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
     assert_eq!(request.method, "GET".to_string());
-    assert_eq!(request.url, "http://localhost:8000/redirect".to_string());
+    assert_eq!(
+        request.url,
+        "http://localhost:8000/redirect-absolute".to_string()
+    );
     assert_eq!(request.headers.len(), 3);
 
     assert_eq!(response.status, 302);
@@ -372,12 +375,16 @@ fn test_redirect() {
         response.get_header_values("Location").get(0).unwrap(),
         "http://localhost:8000/redirected"
     );
+    assert_eq!(
+        response.url,
+        "http://localhost:8000/redirect-absolute".to_string()
+    );
     assert_eq!(client.redirect_count, 0);
 }
 
 #[test]
 fn test_follow_location() {
-    let request_spec = default_get_request("http://localhost:8000/redirect");
+    let request_spec = default_get_request("http://localhost:8000/redirect-absolute");
     let logger = Logger::new(false, false, "", "");
     let options = ClientOptions {
         follow_location: true,
@@ -388,7 +395,7 @@ fn test_follow_location() {
     assert_eq!(options.curl_args(), vec!["-L".to_string()]);
     assert_eq!(
         client.curl_command_line(&request_spec, &context_dir, &options),
-        "curl 'http://localhost:8000/redirect' -L".to_string()
+        "curl 'http://localhost:8000/redirect-absolute' -L".to_string()
     );
 
     let calls = client
@@ -398,19 +405,30 @@ fn test_follow_location() {
 
     let (request1, response1) = calls.get(0).unwrap();
     assert_eq!(request1.method, "GET".to_string());
-    assert_eq!(request1.url, "http://localhost:8000/redirect".to_string());
+    assert_eq!(
+        request1.url,
+        "http://localhost:8000/redirect-absolute".to_string()
+    );
     assert_eq!(request1.headers.len(), 3);
     assert_eq!(response1.status, 302);
     assert!(response1.headers.contains(&Header {
         name: "Location".to_string(),
         value: "http://localhost:8000/redirected".to_string(),
     }));
+    assert_eq!(
+        response1.url,
+        "http://localhost:8000/redirect-absolute".to_string()
+    );
 
     let (request2, response2) = calls.get(1).unwrap();
     assert_eq!(request2.method, "GET".to_string());
     assert_eq!(request2.url, "http://localhost:8000/redirected".to_string());
     assert_eq!(request2.headers.len(), 3);
     assert_eq!(response2.status, 200);
+    assert_eq!(
+        response2.url,
+        "http://localhost:8000/redirected".to_string()
+    );
 
     assert_eq!(client.redirect_count, 1);
 
@@ -784,8 +802,10 @@ fn test_error_ssl() {
     {
         assert_eq!(code, 60);
         let descriptions = [
-            // Windows messages:
+            // Windows 2000 github runner messages:
             "schannel: SEC_E_UNTRUSTED_ROOT (0x80090325) - The certificate chain was issued by an authority that is not trusted.".to_string(),
+            // Windows 10 Enterprise 2009 10.0.19041.1806
+            "schannel: SEC_E_UNTRUSTED_ROOT (0x80090325)".to_string(),
             // Unix-like, before OpenSSL 3.0.0
             "SSL certificate problem: self signed certificate".to_string(),
             // Unix-like, after OpenSSL 3.0.0
@@ -1112,6 +1132,39 @@ fn test_insecure() {
     assert_eq!(response.status, 200);
 }
 
+#[test]
+fn test_head() {
+    let options = ClientOptions {
+        ..Default::default()
+    };
+    let context_dir = ContextDir::default();
+    let mut client = Client::new(None);
+    let logger = Logger::new(false, false, "", "");
+    let request_spec = RequestSpec {
+        method: Method::Head,
+        url: "http://localhost:8000/head".to_string(),
+        headers: vec![],
+        querystring: vec![],
+        form: vec![],
+        multipart: vec![],
+        cookies: vec![],
+        body: Body::Binary(vec![]),
+        content_type: None,
+    };
+    assert_eq!(
+        client.curl_command_line(&request_spec, &context_dir, &options),
+        "curl 'http://localhost:8000/head' --head".to_string()
+    );
+
+    let (request, response) = client.execute(&request_spec, &options, &logger).unwrap();
+    assert_eq!(request.url, "http://localhost:8000/head");
+    assert_eq!(response.status, 200);
+    assert!(response.headers.contains(&Header {
+        name: "Content-Length".to_string(),
+        value: "10".to_string(),
+    }));
+}
+
 #[test]
 fn test_version() {
     // This test if only informative for the time-being
