@@ -284,6 +284,7 @@ pub struct Capture {
     pub space1: Whitespace,
     pub space2: Whitespace,
     pub query: Query,
+    pub filters: Vec<(Whitespace, Filter)>,
     pub line_terminator0: LineTerminator,
 }
 
@@ -292,6 +293,7 @@ pub struct Assert {
     pub line_terminators: Vec<LineTerminator>,
     pub space0: Whitespace,
     pub query: Query,
+    pub filters: Vec<(Whitespace, Filter)>,
     pub space1: Whitespace,
     pub predicate: Predicate,
     pub line_terminator0: LineTerminator,
@@ -301,13 +303,13 @@ pub struct Assert {
 pub struct Query {
     pub source_info: SourceInfo,
     pub value: QueryValue,
-    pub subquery: Option<(Whitespace, Subquery)>,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 #[allow(clippy::large_enum_variant)]
 pub enum QueryValue {
     Status {},
+    Url {},
     Header {
         space0: Whitespace,
         name: Template,
@@ -385,21 +387,6 @@ impl CookieAttributeName {
     }
 }
 
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub struct Subquery {
-    pub source_info: SourceInfo,
-    pub value: SubqueryValue,
-}
-
-#[derive(Clone, Debug, PartialEq, Eq)]
-pub enum SubqueryValue {
-    Regex {
-        space0: Whitespace,
-        value: RegexValue,
-    },
-    Count {},
-}
-
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct Predicate {
     pub not: bool,
@@ -675,6 +662,9 @@ pub enum EntryOption {
     Insecure(InsecureOption),
     FollowLocation(FollowLocationOption),
     MaxRedirect(MaxRedirectOption),
+    Retry(RetryOption),
+    RetryInterval(RetryIntervalOption),
+    RetryMaxCount(RetryMaxCountOption),
     Variable(VariableOption),
     Verbose(VerboseOption),
     VeryVerbose(VeryVerboseOption),
@@ -710,6 +700,36 @@ pub struct CaCertificateOption {
     pub line_terminator0: LineTerminator,
 }
 
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct RetryOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: bool,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct RetryIntervalOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: u64,
+    pub line_terminator0: LineTerminator,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct RetryMaxCountOption {
+    pub line_terminators: Vec<LineTerminator>,
+    pub space0: Whitespace,
+    pub space1: Whitespace,
+    pub space2: Whitespace,
+    pub value: usize,
+    pub line_terminator0: LineTerminator,
+}
+
 #[derive(Clone, Debug, PartialEq, Eq)]
 pub struct VerboseOption {
     pub line_terminators: Vec<LineTerminator>,
@@ -776,3 +796,20 @@ pub enum VariableValue {
     Float(Float),
     String(Template),
 }
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub struct Filter {
+    pub source_info: SourceInfo,
+    pub value: FilterValue,
+}
+
+#[derive(Clone, Debug, PartialEq, Eq)]
+pub enum FilterValue {
+    Count {},
+    Regex {
+        space0: Whitespace,
+        value: RegexValue,
+    },
+    UrlEncode {},
+    UrlDecode {},
+}
