@@ -237,6 +237,9 @@ impl Htmlable for EntryOption {
             EntryOption::Insecure(option) => option.to_html(),
             EntryOption::FollowLocation(option) => option.to_html(),
             EntryOption::MaxRedirect(option) => option.to_html(),
+            EntryOption::Retry(option) => option.to_html(),
+            EntryOption::RetryInterval(option) => option.to_html(),
+            EntryOption::RetryMaxCount(option) => option.to_html(),
             EntryOption::Variable(option) => option.to_html(),
             EntryOption::Verbose(option) => option.to_html(),
             EntryOption::VeryVerbose(option) => option.to_html(),
@@ -329,6 +332,57 @@ impl Htmlable for MaxRedirectOption {
     }
 }
 
+impl Htmlable for RetryOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">retry</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"boolean\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for RetryIntervalOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">retry-interval</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"number\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
+impl Htmlable for RetryMaxCountOption {
+    fn to_html(&self) -> String {
+        let mut buffer = String::from("");
+        add_line_terminators(&mut buffer, self.line_terminators.clone());
+        buffer.push_str("<span class=\"line\">");
+        buffer.push_str(self.space0.to_html().as_str());
+        buffer.push_str("<span class=\"string\">retry-max-count</span>");
+        buffer.push_str(self.space1.to_html().as_str());
+        buffer.push_str("<span>:</span>");
+        buffer.push_str(self.space2.to_html().as_str());
+        buffer.push_str(format!("<span class=\"number\">{}</span>", self.value).as_str());
+        buffer.push_str("</span>");
+        buffer.push_str(self.line_terminator0.to_html().as_str());
+        buffer
+    }
+}
+
 impl Htmlable for VariableOption {
     fn to_html(&self) -> String {
         let mut buffer = String::from("");
@@ -486,6 +540,10 @@ impl Htmlable for Capture {
         buffer.push_str("<span>:</span>");
         buffer.push_str(self.space2.to_html().as_str());
         buffer.push_str(self.query.to_html().as_str());
+        for (space, filter) in self.clone().filters {
+            buffer.push_str(space.to_html().as_str());
+            buffer.push_str(filter.to_html().as_str());
+        }
         buffer.push_str("</span>");
         buffer.push_str(self.line_terminator0.to_html().as_str());
         buffer
@@ -494,12 +552,7 @@ impl Htmlable for Capture {
 
 impl Htmlable for Query {
     fn to_html(&self) -> String {
-        let mut buffer = self.value.clone().to_html();
-        if let Some((space, subquery)) = self.clone().subquery {
-            buffer.push_str(space.to_html().as_str());
-            buffer.push_str(subquery.to_html().as_str());
-        }
-        buffer
+        self.value.clone().to_html()
     }
 }
 
@@ -510,6 +563,9 @@ impl Htmlable for QueryValue {
             QueryValue::Status {} => {
                 buffer.push_str("<span class=\"query-type\">status</span>");
             }
+            QueryValue::Url {} => {
+                buffer.push_str("<span class=\"query-type\">url</span>");
+            }
             QueryValue::Header { space0, name } => {
                 buffer.push_str("<span class=\"query-type\">header</span>");
                 buffer.push_str(space0.to_html().as_str());
@@ -580,26 +636,6 @@ impl Htmlable for RegexValue {
     }
 }
 
-impl Htmlable for Subquery {
-    fn to_html(&self) -> String {
-        let mut buffer = String::from("");
-        match self.value.clone() {
-            SubqueryValue::Regex { value, space0 } => {
-                buffer.push_str("<span class=\"subquery-type\">regex</span>");
-                buffer.push_str(space0.to_html().as_str());
-                // buffer.push_str(
-                //     format!("<span class=\"string\">\"{}\"</span>", value.to_html()).as_str(),
-                // );
-                buffer.push_str(value.to_html().as_str());
-            }
-            SubqueryValue::Count {} => {
-                buffer.push_str("<span class=\"subquery-type\">count</span>")
-            }
-        }
-        buffer
-    }
-}
-
 impl Htmlable for CookiePath {
     fn to_html(&self) -> String {
         let mut buffer = String::from("");
@@ -630,6 +666,10 @@ impl Htmlable for Assert {
         buffer.push_str("<span class=\"line\">");
         buffer.push_str(self.space0.to_html().as_str());
         buffer.push_str(self.query.to_html().as_str());
+        for (space, filter) in self.clone().filters {
+            buffer.push_str(space.to_html().as_str());
+            buffer.push_str(filter.to_html().as_str());
+        }
         buffer.push_str(self.space1.to_html().as_str());
         buffer.push_str(self.predicate.to_html().as_str());
         buffer.push_str("</span>");
@@ -821,40 +861,11 @@ impl Htmlable for RawString {
     fn to_html(&self) -> String {
         let mut buffer = "".to_string();
         buffer.push_str("<span class=\"raw\">");
-        buffer.push_str("<span class=\"line\">```");
-
-        if !self.newline.value.as_str().is_empty() {
-            buffer.push_str(
-                format!(
-                    "</span>{}<span class=\"line\">",
-                    self.newline.value.as_str()
-                )
-                .as_str(),
-            );
-        }
-
-        let mut lines: Vec<String> = regex::Regex::new(r"\n|\r\n")
-            .unwrap()
-            .split(self.value.to_string().trim())
-            .map(|l| xml_escape(l.to_string()))
-            .filter(|l| !l.is_empty())
-            .collect();
-
-        if lines.is_empty() {
-            buffer.push_str("```</span>");
-        } else if lines.len() == 1 {
-            buffer.push_str(encode_html(lines.get(0).unwrap().to_string()).as_str());
-            buffer.push_str("```</span>");
-        } else {
-            buffer.push_str(encode_html(lines.remove(0)).as_str());
-            buffer.push_str("</span>\n");
-            for line in lines {
-                buffer.push_str("<span class=\"line\">");
-                buffer.push_str(encode_html(line).as_str());
-                buffer.push_str("</span>\n");
-            }
-            buffer.push_str("<span class=\"line\">```</span>");
-        }
+        let mut s = "```".to_string();
+        s.push_str(self.newline.value.as_str());
+        s.push_str(self.value.to_string().as_str());
+        s.push_str("```");
+        buffer.push_str(multilines(s).as_str());
         buffer.push_str("</span>");
         buffer
     }
@@ -1010,6 +1021,29 @@ impl Htmlable for Expr {
     }
 }
 
+impl Htmlable for Filter {
+    fn to_html(&self) -> String {
+        self.value.to_html()
+    }
+}
+
+impl Htmlable for FilterValue {
+    fn to_html(&self) -> String {
+        match self {
+            FilterValue::Count {} => "<span class=\"filter-type\">count</span>".to_string(),
+            FilterValue::Regex { space0, value } => {
+                let mut buffer = "".to_string();
+                buffer.push_str("<span class=\"filter-type\">regex</span>");
+                buffer.push_str(space0.to_html().as_str());
+                buffer.push_str(value.to_html().as_str());
+                buffer
+            }
+            FilterValue::UrlEncode {} => "<span class=\"filter-type\">urlEncode</span>".to_string(),
+            FilterValue::UrlDecode {} => "<span class=\"filter-type\">urlDecode</span>".to_string(),
+        }
+    }
+}
+
 fn add_line_terminators(buffer: &mut String, line_terminators: Vec<LineTerminator>) {
     for line_terminator in line_terminators {
         buffer.push_str("<span class=\"line\">");
@@ -1102,6 +1136,27 @@ mod tests {
             raw_string.to_html(),
             "<span class=\"raw\"><span class=\"line\">```</span>\n<span class=\"line\">line1</span>\n<span class=\"line\">line2</span>\n<span class=\"line\">```</span></span>".to_string()
         );
+
+        // ```Hello
+        // ```
+        let raw_string = RawString {
+            newline: Whitespace {
+                value: "".to_string(),
+                source_info: SourceInfo::new(0, 0, 0, 0),
+            },
+            value: Template {
+                quotes: false,
+                elements: vec![TemplateElement::String {
+                    value: "Hello\n".to_string(),
+                    encoded: "unused".to_string(),
+                }],
+                source_info: SourceInfo::new(0, 0, 0, 0),
+            },
+        };
+        assert_eq!(
+            raw_string.to_html(),
+            "<span class=\"raw\"><span class=\"line\">```Hello</span>\n<span class=\"line\">```</span></span>".to_string()
+        );
     }
 
     #[test]
@@ -1114,6 +1169,11 @@ mod tests {
             multilines("<?xml version=\"1.0\"?>\n<drink>café</drink>".to_string()),
             "<span class=\"line\">&lt;?xml version=\"1.0\"?&gt;</span>\n<span class=\"line\">&lt;drink&gt;café&lt;/drink&gt;</span>"
         );
+
+        assert_eq!(
+            multilines("Hello\n".to_string()),
+            "<span class=\"line\">Hello</span>\n<span class=\"line\"></span>"
+        );
     }
 
     #[test]
