@@ -40,6 +40,7 @@ mod cookiepath;
 mod error;
 mod expr;
 mod filename;
+mod filter;
 mod json;
 mod parsers;
 mod predicate;
@@ -49,7 +50,6 @@ mod query;
 mod reader;
 mod sections;
 mod string;
-mod subquery;
 mod template;
 mod url;
 mod xml;
