@@ -23,36 +23,15 @@ use super::cookiepath::cookiepath;
 use super::primitives::*;
 use super::reader::Reader;
 use super::string::*;
-use super::subquery::subquery;
 use super::ParseResult;
 
 pub fn query(reader: &mut Reader) -> ParseResult<'static, Query> {
     let start = reader.state.pos.clone();
     let value = query_value(reader)?;
     let end = reader.state.pos.clone();
-
-    let save = reader.state.clone();
-    let space = zero_or_more_spaces(reader)?;
-    let optional_subquery = if space.value.is_empty() {
-        reader.state = save;
-        None
-    } else {
-        match subquery(reader) {
-            Ok(q) => Some((space, q)),
-            Err(e) => {
-                if e.recoverable {
-                    reader.state = save;
-                    None
-                } else {
-                    return Err(e);
-                }
-            }
-        }
-    };
     Ok(Query {
         source_info: SourceInfo { start, end },
         value,
-        subquery: optional_subquery,
     })
 }
 
@@ -60,6 +39,7 @@ fn query_value(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
     choice(
         vec![
             status_query,
+            url_query,
             header_query,
             cookie_query,
             body_query,
@@ -81,6 +61,11 @@ fn status_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
     Ok(QueryValue::Status {})
 }
 
+fn url_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
+    try_literal("url", reader)?;
+    Ok(QueryValue::Url {})
+}
+
 fn header_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
     try_literal("header", reader)?;
     let space0 = one_or_more_spaces(reader)?;
@@ -199,6 +184,7 @@ fn md5_query(reader: &mut Reader) -> ParseResult<'static, QueryValue> {
 #[cfg(test)]
 mod tests {
     use super::*;
+    use crate::parser::filter::filters;
 
     #[test]
     fn test_query() {
@@ -208,7 +194,6 @@ mod tests {
             Query {
                 source_info: SourceInfo::new(1, 1, 1, 7),
                 value: QueryValue::Status {},
-                subquery: None,
             }
         );
     }
@@ -221,7 +206,6 @@ mod tests {
             Query {
                 source_info: SourceInfo::new(1, 1, 1, 7),
                 value: QueryValue::Status {},
-                subquery: None,
             }
         );
     }
@@ -366,4 +350,30 @@ mod tests {
             },
         );
     }
+
+    #[test]
+    fn test_query_with_filters() {
+        let mut reader = Reader::init("body urlDecode ");
+        assert_eq!(
+            query(&mut reader).unwrap(),
+            Query {
+                source_info: SourceInfo::new(1, 1, 1, 5),
+                value: QueryValue::Body {},
+            }
+        );
+        assert_eq!(
+            filters(&mut reader).unwrap(),
+            vec![(
+                Whitespace {
+                    value: " ".to_string(),
+                    source_info: SourceInfo::new(1, 5, 1, 6)
+                },
+                Filter {
+                    source_info: SourceInfo::new(1, 6, 1, 15),
+                    value: FilterValue::UrlDecode {},
+                }
+            )]
+        );
+        assert_eq!(reader.state.cursor, 14);
+    }
 }
