@@ -16,6 +16,7 @@
  *
  */
 use crate::ast::*;
+use crate::parser::filter::filters;
 
 use super::combinators::*;
 use super::error::*;
@@ -286,7 +287,7 @@ fn capture(reader: &mut Reader) -> ParseResult<'static, Capture> {
     recover(|p1| literal(":", p1), reader)?;
     let space2 = zero_or_more_spaces(reader)?;
     let q = query(reader)?;
-
+    let filters = filters(reader)?;
     let line_terminator0 = line_terminator(reader)?;
     Ok(Capture {
         line_terminators,
@@ -295,6 +296,7 @@ fn capture(reader: &mut Reader) -> ParseResult<'static, Capture> {
         space1,
         space2,
         query: q,
+        filters,
         line_terminator0,
     })
 }
@@ -303,6 +305,7 @@ fn assert(reader: &mut Reader) -> ParseResult<'static, Assert> {
     let line_terminators = optional_line_terminators(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
     let query0 = query(reader)?;
+    let filters = filters(reader)?;
     let space1 = one_or_more_spaces(reader)?;
     let predicate0 = predicate(reader)?;
 
@@ -335,6 +338,7 @@ fn assert(reader: &mut Reader) -> ParseResult<'static, Assert> {
         line_terminators,
         space0,
         query: query0,
+        filters,
         space1,
         predicate: predicate0,
         line_terminator0,
@@ -349,6 +353,9 @@ fn option(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
             option_insecure,
             option_follow_location,
             option_max_redirect,
+            option_retry,
+            option_retry_interval,
+            option_retry_max_count,
             option_variable,
             option_verbose,
             option_very_verbose,
@@ -469,6 +476,74 @@ fn option_max_redirect(reader: &mut Reader) -> ParseResult<'static, EntryOption>
     Ok(EntryOption::MaxRedirect(option))
 }
 
+fn option_retry(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("retry", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let value = nonrecover(boolean, reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+
+    let option = RetryOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        value,
+        line_terminator0,
+    };
+
+    Ok(EntryOption::Retry(option))
+}
+
+fn option_retry_interval(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("retry-interval", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let value = nonrecover(natural, reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+
+    let option = RetryIntervalOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        value,
+        line_terminator0,
+    };
+
+    Ok(EntryOption::RetryInterval(option))
+}
+
+fn option_retry_max_count(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
+    let line_terminators = optional_line_terminators(reader)?;
+    let space0 = zero_or_more_spaces(reader)?;
+    try_literal("retry-max-count", reader)?;
+    let space1 = zero_or_more_spaces(reader)?;
+    try_literal(":", reader)?;
+    let space2 = zero_or_more_spaces(reader)?;
+    let value = nonrecover(natural, reader)?;
+    let line_terminator0 = line_terminator(reader)?;
+
+    // FIXME: try to not unwrap redirect value
+    // and returns an error if not possible
+    let option = RetryMaxCountOption {
+        line_terminators,
+        space0,
+        space1,
+        space2,
+        value: usize::try_from(value).unwrap(),
+        line_terminator0,
+    };
+
+    Ok(EntryOption::RetryMaxCount(option))
+}
+
 fn option_variable(reader: &mut Reader) -> ParseResult<'static, EntryOption> {
     let line_terminators = optional_line_terminators(reader)?;
     let space0 = zero_or_more_spaces(reader)?;
@@ -658,8 +733,8 @@ mod tests {
                                 source_info: SourceInfo::new(2, 8, 2, 18),
                             },
                         },
-                        subquery: None,
                     },
+                    filters: vec![],
                     space1: Whitespace {
                         value: String::from(" "),
                         source_info: SourceInfo::new(2, 18, 2, 19),
@@ -955,12 +1030,12 @@ mod tests {
                 quotes: false,
                 elements: vec![TemplateElement::String {
                     value: "toto".to_string(),
-                    encoded: "toto".to_string()
+                    encoded: "toto".to_string(),
                 }],
                 source_info: SourceInfo {
                     start: Pos { line: 1, column: 1 },
                     end: Pos { line: 1, column: 5 },
-                }
+                },
             })
         );
         let mut reader = Reader::init("\"123\"");
@@ -970,12 +1045,12 @@ mod tests {
                 quotes: true,
                 elements: vec![TemplateElement::String {
                     value: "123".to_string(),
-                    encoded: "123".to_string()
+                    encoded: "123".to_string(),
                 }],
                 source_info: SourceInfo {
                     start: Pos { line: 1, column: 1 },
                     end: Pos { line: 1, column: 6 },
-                }
+                },
             })
         );
     }
@@ -1106,13 +1181,12 @@ mod tests {
                         source_info: SourceInfo::new(1, 13, 1, 23),
                     },
                 },
-                subquery: None,
             }
         );
     }
 
     #[test]
-    fn test_capture_with_subquery() {
+    fn test_capture_with_filter() {
         let mut reader = Reader::init("token: header \"Location\" regex \"token=(.*)\"");
         let capture0 = capture(&mut reader).unwrap();
 
@@ -1134,37 +1208,13 @@ mod tests {
                         source_info: SourceInfo::new(1, 15, 1, 25),
                     },
                 },
-
-                subquery: Some((
-                    Whitespace {
-                        value: " ".to_string(),
-                        source_info: SourceInfo::new(1, 25, 1, 26),
-                    },
-                    Subquery {
-                        source_info: SourceInfo::new(1, 26, 1, 44),
-                        value: SubqueryValue::Regex {
-                            space0: Whitespace {
-                                value: " ".to_string(),
-                                source_info: SourceInfo::new(1, 31, 1, 32),
-                            },
-                            value: RegexValue::Template(Template {
-                                quotes: true,
-                                elements: vec![TemplateElement::String {
-                                    value: "token=(.*)".to_string(),
-                                    encoded: "token=(.*)".to_string(),
-                                }],
-                                source_info: SourceInfo::new(1, 32, 1, 44),
-                            }),
-                        },
-                    }
-                )),
             }
         );
         assert_eq!(reader.state.cursor, 43);
     }
 
     #[test]
-    fn test_capture_with_subquery_error() {
+    fn test_capture_with_filter_error() {
         let mut reader = Reader::init("token: header \"Location\" regex ");
         let error = capture(&mut reader).err().unwrap();
         assert_eq!(
@@ -1223,7 +1273,6 @@ mod tests {
                         source_info: SourceInfo::new(1, 8, 1, 18),
                     },
                 },
-                subquery: None,
             }
         );
     }
