@@ -31,7 +31,7 @@ fn strip_bom(bytes: &mut Vec<u8>) {
 /// Similar to the standard read_to_string()
 /// But remove any existing BOM
 pub fn read_to_string(filename: &str) -> Result<String, CliError> {
-    let mut f = match File::open(&filename) {
+    let mut f = match File::open(filename) {
         Ok(f) => f,
         Err(e) => {
             return Err(CliError {
@@ -39,7 +39,7 @@ pub fn read_to_string(filename: &str) -> Result<String, CliError> {
             })
         }
     };
-    let metadata = fs::metadata(&filename).expect("unable to read metadata");
+    let metadata = fs::metadata(filename).expect("unable to read metadata");
     let mut buffer = vec![0; metadata.len() as usize];
     if let Err(e) = f.read(&mut buffer) {
         return Err(CliError {
