@@ -247,30 +247,33 @@ impl ToJson for Cookie {
 
 impl ToJson for Capture {
     fn to_json(&self) -> JValue {
-        let attributes = vec![
+        let mut attributes = vec![
             ("name".to_string(), JValue::String(self.name.value.clone())),
             ("query".to_string(), self.query.to_json()),
         ];
+        if !self.filters.is_empty() {
+            let filters = JValue::List(self.filters.iter().map(|(_, f)| f.to_json()).collect());
+            attributes.push(("filters".to_string(), filters));
+        }
         JValue::Object(attributes)
     }
 }
 
 impl ToJson for Assert {
     fn to_json(&self) -> JValue {
-        let attributes = vec![
-            ("query".to_string(), self.query.to_json()),
-            ("predicate".to_string(), self.predicate.to_json()),
-        ];
+        let mut attributes = vec![("query".to_string(), self.query.to_json())];
+        if !self.filters.is_empty() {
+            let filters = JValue::List(self.filters.iter().map(|(_, f)| f.to_json()).collect());
+            attributes.push(("filters".to_string(), filters));
+        }
+        attributes.push(("predicate".to_string(), self.predicate.to_json()));
         JValue::Object(attributes)
     }
 }
 
 impl ToJson for Query {
     fn to_json(&self) -> JValue {
-        let mut attributes = query_value_attributes(&self.value);
-        if let Some((_, subquery)) = self.subquery.clone() {
-            attributes.push(("subquery".to_string(), subquery.to_json()));
-        }
+        let attributes = query_value_attributes(&self.value);
         JValue::Object(attributes)
     }
 }
@@ -281,6 +284,9 @@ fn query_value_attributes(query_value: &QueryValue) -> Vec<(String, JValue)> {
         QueryValue::Status {} => {
             attributes.push(("type".to_string(), JValue::String("status".to_string())));
         }
+        QueryValue::Url {} => {
+            attributes.push(("type".to_string(), JValue::String("url".to_string())));
+        }
         QueryValue::Body {} => {
             attributes.push(("type".to_string(), JValue::String("body".to_string())));
         }
@@ -324,28 +330,6 @@ fn query_value_attributes(query_value: &QueryValue) -> Vec<(String, JValue)> {
     attributes
 }
 
-impl ToJson for Subquery {
-    fn to_json(&self) -> JValue {
-        self.value.to_json()
-    }
-}
-
-impl ToJson for SubqueryValue {
-    fn to_json(&self) -> JValue {
-        let mut attributes = vec![];
-        match self {
-            SubqueryValue::Regex { value, .. } => {
-                attributes.push(("type".to_string(), JValue::String("regex".to_string())));
-                attributes.push(("expr".to_string(), value.to_json()));
-            }
-            SubqueryValue::Count { .. } => {
-                attributes.push(("type".to_string(), JValue::String("count".to_string())));
-            }
-        }
-        JValue::Object(attributes)
-    }
-}
-
 impl ToJson for RegexValue {
     fn to_json(&self) -> JValue {
         match self {
@@ -489,7 +473,7 @@ impl ToJson for RawString {
     }
 }
 
-impl ToJson for hurl_core::ast::JsonValue {
+impl ToJson for JsonValue {
     fn to_json(&self) -> JValue {
         match self {
             JsonValue::Null {} => JValue::Null {},
@@ -510,12 +494,40 @@ impl ToJson for hurl_core::ast::JsonValue {
     }
 }
 
-impl ToJson for hurl_core::ast::JsonListElement {
+impl ToJson for JsonListElement {
     fn to_json(&self) -> JValue {
         self.value.to_json()
     }
 }
 
+impl ToJson for Filter {
+    fn to_json(&self) -> JValue {
+        self.value.to_json()
+    }
+}
+
+impl ToJson for FilterValue {
+    fn to_json(&self) -> JValue {
+        let mut attributes = vec![];
+        match self {
+            FilterValue::Regex { value, .. } => {
+                attributes.push(("type".to_string(), JValue::String("regex".to_string())));
+                attributes.push(("expr".to_string(), value.to_json()));
+            }
+            FilterValue::Count { .. } => {
+                attributes.push(("type".to_string(), JValue::String("count".to_string())));
+            }
+            FilterValue::UrlEncode { .. } => {
+                attributes.push(("type".to_string(), JValue::String("urlEncode".to_string())));
+            }
+            FilterValue::UrlDecode { .. } => {
+                attributes.push(("type".to_string(), JValue::String("urlDecode".to_string())));
+            }
+        }
+        JValue::Object(attributes)
+    }
+}
+
 #[cfg(test)]
 pub mod tests {
     use super::*;
@@ -663,7 +675,6 @@ pub mod tests {
                     source_info: SourceInfo::new(0, 0, 0, 0),
                 },
             },
-            subquery: None,
         }
     }
 
@@ -680,6 +691,7 @@ pub mod tests {
             space1: whitespace(),
             space2: whitespace(),
             query: header_query(),
+            filters: vec![],
             line_terminator0: line_terminator(),
         }
     }
@@ -689,6 +701,7 @@ pub mod tests {
             line_terminators: vec![],
             space0: whitespace(),
             query: header_query(),
+            filters: vec![],
             space1: whitespace(),
             predicate: equal_int_predicate(10),
             line_terminator0: line_terminator(),
