@@ -26,6 +26,7 @@ pub enum Token {
     SectionHeader(String),
     QueryType(String),
     PredicateType(String),
+    FilterType(String),
     Not(String),
     Keyword(String),
 
@@ -368,6 +369,10 @@ impl Tokenizable for Capture {
         tokens.push(Token::Colon(String::from(":")));
         tokens.append(&mut self.space2.tokenize());
         tokens.append(&mut self.query.tokenize());
+        for (space, filter) in &self.filters {
+            tokens.append(&mut space.clone().tokenize());
+            tokens.append(&mut filter.tokenize());
+        }
         tokens.append(&mut self.line_terminator0.tokenize());
         tokens
     }
@@ -385,6 +390,10 @@ impl Tokenizable for Assert {
         );
         tokens.append(&mut self.space0.tokenize());
         tokens.append(&mut self.query.tokenize());
+        for (space, filter) in &self.filters {
+            tokens.append(&mut space.clone().tokenize());
+            tokens.append(&mut filter.tokenize());
+        }
         tokens.append(&mut self.space1.tokenize());
         // TODO reconvert back your first predicate for jsonpath
         // so that you can use your firstX predicate for other query
@@ -396,12 +405,7 @@ impl Tokenizable for Assert {
 
 impl Tokenizable for Query {
     fn tokenize(&self) -> Vec<Token> {
-        let mut tokens: Vec<Token> = self.value.clone().tokenize();
-        if let Some((space, subquery)) = &self.subquery {
-            tokens.append(&mut space.clone().tokenize());
-            tokens.append(&mut subquery.tokenize());
-        }
-        tokens
+        self.value.clone().tokenize()
     }
 }
 
@@ -410,6 +414,7 @@ impl Tokenizable for QueryValue {
         let mut tokens: Vec<Token> = vec![];
         match self.clone() {
             QueryValue::Status {} => tokens.push(Token::QueryType(String::from("status"))),
+            QueryValue::Url {} => tokens.push(Token::QueryType(String::from("url"))),
             QueryValue::Header { space0, name } => {
                 tokens.push(Token::QueryType(String::from("header")));
                 tokens.append(&mut space0.tokenize());
@@ -483,23 +488,6 @@ impl Tokenizable for CookieAttribute {
     }
 }
 
-impl Tokenizable for Subquery {
-    fn tokenize(&self) -> Vec<Token> {
-        let mut tokens: Vec<Token> = vec![];
-        match self.value.clone() {
-            SubqueryValue::Regex { space0, value } => {
-                tokens.push(Token::QueryType(String::from("regex")));
-                tokens.append(&mut space0.tokenize());
-                tokens.append(&mut value.tokenize());
-            }
-            SubqueryValue::Count { .. } => {
-                tokens.push(Token::QueryType(String::from("count")));
-            }
-        }
-        tokens
-    }
-}
-
 impl Tokenizable for Predicate {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -823,6 +811,9 @@ impl Tokenizable for EntryOption {
             EntryOption::Insecure(option) => option.tokenize(),
             EntryOption::FollowLocation(option) => option.tokenize(),
             EntryOption::MaxRedirect(option) => option.tokenize(),
+            EntryOption::Retry(option) => option.tokenize(),
+            EntryOption::RetryInterval(option) => option.tokenize(),
+            EntryOption::RetryMaxCount(option) => option.tokenize(),
             EntryOption::Variable(option) => option.tokenize(),
             EntryOption::Verbose(option) => option.tokenize(),
             EntryOption::VeryVerbose(option) => option.tokenize(),
@@ -935,6 +926,69 @@ impl Tokenizable for MaxRedirectOption {
     }
 }
 
+impl Tokenizable for RetryOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("retry".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.push(Token::Boolean(self.value.to_string()));
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
+impl Tokenizable for RetryIntervalOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("retry-interval".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.push(Token::Number(self.value.to_string()));
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
+impl Tokenizable for RetryMaxCountOption {
+    fn tokenize(&self) -> Vec<Token> {
+        let mut tokens: Vec<Token> = vec![];
+        tokens.append(
+            &mut self
+                .line_terminators
+                .iter()
+                .flat_map(|e| e.tokenize())
+                .collect(),
+        );
+        tokens.append(&mut self.space0.tokenize());
+        tokens.push(Token::String("retry-max-count".to_string()));
+        tokens.append(&mut self.space1.tokenize());
+        tokens.push(Token::Colon(String::from(":")));
+        tokens.append(&mut self.space2.tokenize());
+        tokens.push(Token::Number(self.value.to_string()));
+        tokens.append(&mut self.line_terminator0.tokenize());
+        tokens
+    }
+}
+
 impl Tokenizable for VariableOption {
     fn tokenize(&self) -> Vec<Token> {
         let mut tokens: Vec<Token> = vec![];
@@ -1020,3 +1074,20 @@ impl Tokenizable for VeryVerboseOption {
         tokens
     }
 }
+
+impl Tokenizable for Filter {
+    fn tokenize(&self) -> Vec<Token> {
+        match self.value.clone() {
+            FilterValue::Regex { space0, value } => {
+                let mut tokens: Vec<Token> = vec![];
+                tokens.push(Token::FilterType(String::from("regex")));
+                tokens.append(&mut space0.tokenize());
+                tokens.append(&mut value.tokenize());
+                tokens
+            }
+            FilterValue::Count { .. } => vec![Token::FilterType(String::from("count"))],
+            FilterValue::UrlEncode { .. } => vec![Token::FilterType(String::from("urlEncode"))],
+            FilterValue::UrlDecode { .. } => vec![Token::FilterType(String::from("urlDecode"))],
+        }
+    }
+}
