@@ -57,7 +57,7 @@ impl Lintable<Request> for Request {
         if !self.space0.value.is_empty() {
             errors.push(Error {
                 source_info: self.clone().space0.source_info,
-                inner: LinterError::UnneccessarySpace {},
+                inner: LinterError::UnnecessarySpace {},
             });
         }
         if self.space1.value != " " {
@@ -107,7 +107,7 @@ impl Lintable<Response> for Response {
         if !self.space0.value.is_empty() {
             errors.push(Error {
                 source_info: self.clone().space0.source_info,
-                inner: LinterError::UnneccessarySpace {},
+                inner: LinterError::UnnecessarySpace {},
             });
         }
         errors
@@ -214,10 +214,16 @@ impl Lintable<Assert> for Assert {
     }
 
     fn lint(&self) -> Assert {
+        let filters = self
+            .filters
+            .iter()
+            .map(|(_, f)| (one_whitespace(), f.lint()))
+            .collect();
         Assert {
             line_terminators: self.line_terminators.clone(),
             space0: empty_whitespace(),
             query: self.query.lint(),
+            filters,
             space1: one_whitespace(),
             predicate: self.predicate.lint(),
             line_terminator0: self.line_terminator0.clone(),
@@ -232,6 +238,11 @@ impl Lintable<Capture> for Capture {
     }
 
     fn lint(&self) -> Capture {
+        let filters = self
+            .filters
+            .iter()
+            .map(|(_, f)| (one_whitespace(), f.lint()))
+            .collect();
         Capture {
             line_terminators: self.clone().line_terminators,
             space0: empty_whitespace(),
@@ -239,6 +250,7 @@ impl Lintable<Capture> for Capture {
             space1: empty_whitespace(),
             space2: one_whitespace(),
             query: self.query.lint(),
+            filters,
             line_terminator0: self.line_terminator0.lint(),
         }
     }
@@ -254,10 +266,6 @@ impl Lintable<Query> for Query {
         Query {
             source_info: SourceInfo::new(0, 0, 0, 0),
             value: self.value.lint(),
-            subquery: self
-                .subquery
-                .clone()
-                .map(|(_, s)| (one_whitespace(), s.lint())),
         }
     }
 }
@@ -271,6 +279,7 @@ impl Lintable<QueryValue> for QueryValue {
     fn lint(&self) -> QueryValue {
         match self {
             QueryValue::Status {} => QueryValue::Status {},
+            QueryValue::Url {} => QueryValue::Url {},
             QueryValue::Header { name, .. } => QueryValue::Header {
                 name: name.clone(),
                 space0: one_whitespace(),
@@ -313,19 +322,6 @@ impl Lintable<QueryValue> for QueryValue {
     }
 }
 
-impl Lintable<Subquery> for Subquery {
-    fn errors(&self) -> Vec<Error> {
-        let errors = vec![];
-        errors
-    }
-
-    fn lint(&self) -> Subquery {
-        let source_info = SourceInfo::new(0, 0, 0, 0);
-        let value = self.value.lint();
-        Subquery { source_info, value }
-    }
-}
-
 impl Lintable<RegexValue> for RegexValue {
     fn errors(&self) -> Vec<Error> {
         let errors = vec![];
@@ -339,22 +335,6 @@ impl Lintable<RegexValue> for RegexValue {
         }
     }
 }
-impl Lintable<SubqueryValue> for SubqueryValue {
-    fn errors(&self) -> Vec<Error> {
-        let errors = vec![];
-        errors
-    }
-
-    fn lint(&self) -> SubqueryValue {
-        match self {
-            SubqueryValue::Regex { value, .. } => SubqueryValue::Regex {
-                space0: one_whitespace(),
-                value: value.lint(),
-            },
-            SubqueryValue::Count {} => SubqueryValue::Count {},
-        }
-    }
-}
 
 impl Lintable<CookieAttribute> for CookieAttribute {
     fn errors(&self) -> Vec<Error> {
@@ -746,7 +726,7 @@ impl Lintable<LineTerminator> for LineTerminator {
                 if !self.space0.value.is_empty() {
                     errors.push(Error {
                         source_info: self.clone().space0.source_info,
-                        inner: LinterError::UnneccessarySpace {},
+                        inner: LinterError::UnnecessarySpace {},
                     });
                 }
             }
@@ -819,6 +799,37 @@ impl Lintable<EntryOption> for EntryOption {
     }
 }
 
+impl Lintable<Filter> for Filter {
+    fn errors(&self) -> Vec<Error> {
+        let errors = vec![];
+        errors
+    }
+
+    fn lint(&self) -> Filter {
+        Filter {
+            source_info: SourceInfo::new(0, 0, 0, 0),
+            value: self.value.lint(),
+        }
+    }
+}
+
+impl Lintable<FilterValue> for FilterValue {
+    fn errors(&self) -> Vec<Error> {
+        let errors = vec![];
+        errors
+    }
+
+    fn lint(&self) -> FilterValue {
+        match self {
+            FilterValue::Regex { value, .. } => FilterValue::Regex {
+                space0: one_whitespace(),
+                value: value.lint(),
+            },
+            f => f.clone(),
+        }
+    }
+}
+
 #[cfg(test)]
 mod tests {
     use super::*;
